@@ -1,7 +1,7 @@
 
 /*
  *  agCgi.c
- *  $Id: agCgi.c,v 1.3 2002/02/03 03:31:16 bkorb Exp $
+ *  $Id: agCgi.c,v 1.11 2003/05/10 03:03:20 bkorb Exp $
  *
  *  This is a CGI wrapper for AutoGen.  It will take POST-method
  *  name-value pairs and emit AutoGen definitions to a spawned
@@ -9,7 +9,7 @@
  */
 
 /*
- *  AutoGen-cgi copyright 2001-2002 Bruce Korb
+ *  AutoGen-cgi copyright 2001-2003 Bruce Korb
  *
  *  AutoGen-cgi is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -27,15 +27,6 @@
  *             59 Temple Place - Suite 330,
  *             Boston,  MA  02111-1307, USA.
  */
-#include "autogen.h"
-
-#include "cgi-fsm.h"
-
-#ifdef HAVE_FCNTL_H
-#  include <fcntl.h>
-#else
-#  error NEED  <fcntl.h>
-#endif
 
 typedef struct {
     const char*  pzName;
@@ -78,101 +69,119 @@ typedef enum {
     NAME_CT
 } tNameIdx;
 
-#define pzMethod nameValueMap[ REQUEST_METHOD_IDX ].pzValue
-#define pzQuery  nameValueMap[ QUERY_STRING_IDX   ].pzValue
+#define pzCgiMethod nameValueMap[ REQUEST_METHOD_IDX ].pzValue
+#define pzCgiQuery  nameValueMap[ QUERY_STRING_IDX   ].pzValue
+#define pzCgiLength nameValueMap[ CONTENT_LENGTH_IDX ].pzValue
 
 static const char zOops[] =
 "Content-type: text/plain\n\n"
 "AutoGen form processing error:\n";
 
-#define zNil     ((char*)(zOops + sizeof( zOops ) - 1))
-
 static char* parseInput( char* pzSrc, int len );
 
 EXPORT void
 loadCgi( void )
 {
-    int textLen = 0;
-    char* pzText  = NULL;
-
+    /*
+     *  Redirect stderr to a file.  If it gets used, we must trap it
+     *  and emit the content-type: preamble before actually emitting it.
+     *  First, tho, do a simple stderr->stdout redirection just in case
+     *  we stumble before we're done with this.
+     */
     dup2( STDOUT_FILENO, STDERR_FILENO );
-    (void)fdopen( STDERR_FILENO, "w" );
+    (void)fdopen( STDERR_FILENO, "w" FOPEN_BINARY_FLAG );
+    pzOopsPrefix = zOops;
+    {
+        int tmpfd;
+        char* pz = getenv( "TEMP" );
+        if (pz == NULL) {
+            pz = getenv( "TMP" );
+            if (pz == NULL)
+                pz = "/tmp";
+        }
 
+        pzTmpStderr = aprf( "%s/agtmp.XXXXXX", pz );
+        TAGMEM( pzTmpStderr, "temp stderr file template" );
+        tmpfd = mkstemp( pzTmpStderr );
+        if (tmpfd < 0)
+            AG_ABEND( aprf("failed to create temp file from `%s'", pzTmpStderr));
+        dup2( tmpfd, STDERR_FILENO );
+        close( tmpfd );
+    }
+
+    /*
+     *  Pull the CGI-relevant environment variables.  Anything we don't find
+     *  gets an empty string default.
+     */
     {
         tNameMap* pNM = nameValueMap;
-        tNameIdx  ix  = SERVER_SOFTWARE_IDX;
+        tNameIdx  ix  = 0;
 
         do  {
             pNM->pzValue = getenv( pNM->pzName );
             if (pNM->pzValue == NULL)
-                pNM->pzValue = zNil;
+                pNM->pzValue = "";
         } while (pNM++, ++ix < NAME_CT);
     }
 
-    textLen = atoi( nameValueMap[ CONTENT_LENGTH_IDX ].pzValue );
-
-    if (strcasecmp( pzMethod, "POST" ) == 0) {
-        if (textLen == 0)
-            AG_ABEND( "No CGI data were received" );
-
-        pzText  = malloc( (textLen + 32) & ~0x000F );
-        if (pzText == NULL)
-            AG_ABEND( asprintf( "%s: %d bytes for CGI input",
-                                zAllocErr, textLen ));
-
-        if (fread( pzText, 1, textLen, stdin ) != textLen)
-            AG_ABEND( asprintf( zCannot, errno, "read", "CGI text",
-                                strerror( errno )));
-
-        pzText[ textLen ] = '\0';
-
-        pzQuery = pzText;
-        pzText  = parseInput( pzText, textLen );
-		AGFREE( pzQuery );
-
-    } else if (strcasecmp( pzMethod, "GET" ) == 0) {
-        if (textLen == 0)
-            textLen = strlen( pzQuery );
-        pzText = parseInput( pzQuery, textLen );
-
-    } else
-        AG_ABEND( "invalid request method" );
-
-    pzText = AGREALOC( pzText, strlen( pzText )+1, "CGI input" );
-    pzOopsPrefix = zOops;
-
     pBaseCtx = (tScanCtx*)AGALOC( sizeof( tScanCtx ), "CGI context" );
     memset( (void*)pBaseCtx, 0, sizeof( tScanCtx ));
+
+    {
+        int   textLen = atoi( pzCgiLength );
+        char* pzText;
+
+        if (strcasecmp( pzCgiMethod, "POST" ) == 0) {
+            if (textLen == 0)
+                AG_ABEND( "No CGI data were received" );
+
+            pzText  = AGALOC( textLen + 1, "CGI POST text" );
+            if (fread( pzText, 1, textLen, stdin ) != textLen)
+                AG_ABEND( aprf( zCannot, errno, "read", "CGI text",
+                                strerror( errno )));
+
+            pzText[ textLen ] = NUL;
+
+            pBaseCtx->pzData = parseInput( pzText, textLen );
+            AGFREE( pzText );
+
+        } else if (strcasecmp( pzCgiMethod, "GET" ) == 0) {
+            if (textLen == 0)
+                textLen = strlen( pzCgiQuery );
+            pBaseCtx->pzData = parseInput( pzCgiQuery, textLen );
+
+        } else {
+            AG_ABEND( aprf( "invalid CGI request method: ``%s''", pzCgiMethod ));
+            /* NOTREACHED */
+#ifdef  WARNING_WATCH
+            pzText = NULL;
+#endif
+        }
+    }
+
     pBaseCtx->lineNo     = 1;
     pBaseCtx->pzFileName = "@@ CGI Definitions @@";
-    pBaseCtx->pzScan     = \
-    pBaseCtx->pzData     = pzText;
+    pBaseCtx->pzScan     = pBaseCtx->pzData;
 }
 
 
 static char*
 parseInput( char* pzSrc, int len )
 {
-    tSCC zDef[] = "Autogen Definitions cgi;\n";
-    int   outlen = (len * 2) + sizeof( zDef );
-    char* pzRes = AGALOC( outlen, "CGI Definitions" );
+    tSCC   zDef[] = "Autogen Definitions cgi;\n";
+#   define defLen   (sizeof( zDef ) - 1)
+    char*  pzRes  = AGALOC( (len * 2) + defLen + 1, "CGI Definitions" );
 
-    if (pzRes == NULL)
-        pzRes = "cannout allocate output buffer\n";
-
-    else {
-        strcpy( pzRes, zDef );
-        if (cgi_run_fsm( pzSrc, len, pzRes + sizeof( zDef ) - 1, outlen )
-            == CGI_ST_DONE)
-            return pzRes;
-    }
-
-    AG_ABEND( pzRes );
+    memcpy( pzRes, zDef, defLen );
+    (void)cgi_run_fsm( pzSrc, len, pzRes + defLen, len*2 );
+    return AGREALOC( pzRes, strlen( pzRes )+1, "CGI input" );
 }
 
 /*
  * Local Variables:
+ * mode: C
+ * tab-width: 4
  * c-file-style: "stroustrup"
  * indent-tabs-mode: nil
  * End:
- * end of autogen.c */
+ * end of agen5/agCgi.c */
