@@ -1,11 +1,11 @@
 /*
  *  agShell
- *  $Id: agShell.c,v 1.25 2002/03/27 05:15:11 bkorb Exp $
+ *  $Id: agShell.c,v 1.32 2003/04/21 03:27:48 bkorb Exp $
  *  Manage a server shell process
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -24,22 +24,6 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#include "autogen.h"
-
-#ifdef HAVE_FCNTL_H
-#  include <fcntl.h>
-#else
-#  error NEED  <fcntl.h>
-#endif
-
-#include <signal.h>
-
-#if HAVE_SYS_PROCSET_H
-#  include <sys/procset.h>
-#endif
-
-tSCC   zTxtBlock[] = "Text Block";
-
 #ifndef SHELL_ENABLED
  void closeServer( void ) { }
 
@@ -229,15 +213,21 @@ chainOpen( int       stdinFd,
 
     /*
      *  If the arg list does not have a program,
-     *  assume the "SHELL" from the environment, or, failing
+     *  assume the zShellProg from the environment, or, failing
      *  that, then sh.  Set argv[0] to whatever we decided on.
      */
     if (pzShell = *ppArgs,
-       (pzShell == NULL) || (*pzShell == NUL)){
+       (pzShell == NULL) || (*pzShell == NUL)) {
 
-        pzShell = getenv( "SHELL" );
-        if (pzShell == NULL)
-            pzShell = "sh";
+        if (pzShellProgram != NULL)
+            pzShell = pzShellProgram;
+
+        else {
+            pzShell = getenv( zShellEnv );
+            if (pzShell == NULL)
+                pzShell = "sh";
+            pzShellProgram = pzShell;
+        }
 
         *ppArgs = pzShell;
     }
@@ -330,8 +320,10 @@ chainOpen( int       stdinFd,
         fprintf( pfTrace, "Server shell %s starts\n", pzShell );
 #endif
     execvp( (char*)pzShell, (char**)ppArgs );
-    AG_ABEND( asprintf( "Could not execvp( '%s', ... ):  %d - %s\n",
-                        pzShell, errno, strerror( errno )));
+    AG_ABEND( aprf( "Could not execvp( '%s', ... ):  %d - %s\n",
+                    pzShell, errno, strerror( errno )));
+    /* NOTREACHED */
+    return -1;
 }
 
 
@@ -406,7 +398,7 @@ loadData( FILE* fp )
 
     textSize = 4096;
     pzScan   = \
-    pzText   = AGALOC( textSize, zTxtBlock );
+    pzText   = AGALOC( textSize, "Text Block" );
 
     *pzText  = NUL;
 
@@ -453,10 +445,10 @@ loadData( FILE* fp )
             size_t off = (size_t)(pzScan - pzText);
             void*  p;
             textSize += 4096;
-            p = AGREALOC( (void*)pzText, textSize, NULL );
+            p = AGREALOC( (void*)pzText, textSize, "expanding text" );
             if (p == NULL) {
                 tSCC zRTB[] = "Realloc Text Block";
-                AG_ABEND( asprintf( zAllocWhat, textSize, zRTB ));
+                AG_ABEND( aprf( zAllocWhat, textSize, zRTB ));
             }
 
             pzText   = (char*)p;
@@ -501,7 +493,7 @@ runShell( const char*  pzCmd )
      *  THEN return the nil string.
      */
     if (serverId <= 0) {
-        char* pz = (char*)AGALOC( 1, zTxtBlock );
+        char* pz = (char*)AGALOC( 1, "Text Block" );
 
         *pz = NUL;
         return pz;
@@ -536,7 +528,7 @@ runShell( const char*  pzCmd )
         if (pz == NULL) {
             fprintf( pfTrace, zCmdFail, pzCmd );
             closeServer();
-            pz = (char*)AGALOC( 1, zTxtBlock );
+            pz = (char*)AGALOC( 1, "Text Block" );
 
             *pz = NUL;
 
@@ -551,7 +543,9 @@ runShell( const char*  pzCmd )
 #endif /* ! SHELL_ENABLED */
 /*
  * Local Variables:
+ * mode: C
+ * tab-width: 4
  * c-file-style: "stroustrup"
  * indent-tabs-mode: nil
  * End:
- * end of agShell.c */
+ * end of agen5/agShell.c */
