@@ -1,7 +1,7 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 1.26 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: agUtils.c,v 1.35 2003/05/31 22:59:15 bkorb Exp $
  *  This is the main routine for autogen.
  */
 
@@ -25,32 +25,11 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#include <time.h>
-#include <utime.h>
-#include <ctype.h>
-#include <assert.h>
-
-#include "autogen.h"
-
-#if defined( HAVE_POSIX_SYSINFO )
-#  include <sys/systeminfo.h>
-
-#elif defined( HAVE_UNAME_SYSCALL )
-#  include <sys/utsname.h>
-
-#endif
-
 STATIC void addSysEnv( char* pzEnvName );
-
-#ifdef MEMDEBUG
-#  include "snprintfv/mem.h"
-   static void finalMemCheck( void );
-#endif
-
 STATIC tCC* skipQuote( tCC* pzQte );
 
 #ifndef HAVE_STRLCPY
-    size_t
+size_t
 strlcpy( char* dest, tCC* src, size_t n )
 {
     char* pz = dest;
@@ -86,14 +65,7 @@ aprf( const char* pzFmt, ... )
     va_start( ap, pzFmt );
     (void)vasprintf( &pz, pzFmt, ap );
     va_end( ap );
-#ifdef MEMDEBUG
-    {
-        char* pzDup;
-        AGDUPSTR( pzDup, pz, "aprf" );
-        free( pz );
-        pz = pzDup;
-    }
-#endif
+
     if (pz == NULL) {
         tSCC zMsg[] = "could not allocate for or formatting failed on:\n";
         char z[ 256 ];
@@ -109,6 +81,31 @@ aprf( const char* pzFmt, ... )
 EXPORT void
 doOptions( int arg_ct, char** arg_vec )
 {
+    void ag_init( void );
+    /*
+     *  Initialize all the Scheme functions.
+     */
+    ag_init();
+    pzLastScheme = zSchemeInit;
+    ag_scm_c_eval_string_from_file_line( zSchemeInit, "directive.h",
+                                         SCHEME_INIT_LINE );
+#ifndef scm_t_port
+    {
+        tSCC zInitRest[] =
+            "(add-hook! before-error-hook error-source-line)\n"
+            "(use-modules (ice-9 stack-catch))";
+        pzLastScheme = zInitRest;
+        ag_scm_c_eval_string_from_file_line( zInitRest, __FILE__, __LINE__-3 );
+    }
+#endif
+    if (OPT_VALUE_TRACE > TRACE_NOTHING) {
+        tSCC zBT[] = "(debug-enable 'backtrace)";
+        pzLastScheme = zBT;
+        ag_scm_c_eval_string_from_file_line( zBT, __FILE__, __LINE__ - 2 );
+    }
+    pzLastScheme = NULL;
+
+    procState = PROC_STATE_OPTIONS;
     /*
      *  Set the last resort search directory first (lowest priority)
      */
@@ -136,6 +133,7 @@ doOptions( int arg_ct, char** arg_vec )
         default:
             fprintf( stderr, zOnlyOneSrc, pzProg );
             USAGE( EXIT_FAILURE );
+            /* NOTREACHED */
 
         case 0:
             if (! HAVE_OPT( DEFINITIONS ))
@@ -208,6 +206,7 @@ doOptions( int arg_ct, char** arg_vec )
             if (strchr( pz, '=' ) == NULL) {
                 size_t siz = strlen( pz )+3;
                 char*  p   = AGALOC( siz, "env define" );
+
                 strcpy( p, pz );
                 strcpy( p+siz-3, "=1" );
                 pz = p;
@@ -600,7 +599,9 @@ skipExpression( tCC* pzSrc, size_t len )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of agUtils.c */
+ * end of agen5/agUtils.c */
