@@ -1,7 +1,7 @@
 
 /*
  *  agUtils.h
- *  $Id: agUtils.h,v 1.11 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: agUtils.h,v 1.16 2003/05/03 23:50:55 bkorb Exp $
  *  Utilitarian definitions for AutoGen
  */
 
@@ -28,15 +28,42 @@
 #define AUTOGEN_UTILS_H
 
 #include "config.h"
-#include "compat/compat.h"
 
+#include <sys/types.h>
+#include <sys/mman.h>
+#include <sys/param.h>
+#include <sys/wait.h>
+
+#if HAVE_SYS_PROCSET_H
+#  include <sys/procset.h>
+#endif
+
+#if defined( HAVE_POSIX_SYSINFO )
+#  include <sys/systeminfo.h>
+
+#elif defined( HAVE_UNAME_SYSCALL )
+#  include <sys/utsname.h>
+
+#endif
+
+#ifndef HAVE_STRSIGNAL
+char * strsignal( int signo );
+#endif
+
+#include <assert.h>
+#include <ctype.h>
+#include <fcntl.h>
+#include <signal.h>
+#include <string.h>
 #include <time.h>
 #include <utime.h>
-#include <sys/mman.h>
+#include REGEX_HEADER
 
 #include <guile/gh.h>
 
 #include "opts.h"
+#include "directive.h"
+#include "defParse.h"
 #include "snprintfv/printf.h"
 
 #ifndef STR
@@ -79,7 +106,9 @@ typedef char* tpChar;
 #endif /* AUTOGEN_UTILS_H */
 /*
  * Local Variables:
- * c-file-style: "Stroustrup"
+ * mode: C
+ * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of agUtils.h */
+ * end of agen5/agUtils.h */
