@@ -1,7 +1,7 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 1.35 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: autogen.h,v 1.45 2003/05/31 22:59:15 bkorb Exp $
  *  Global header file for AutoGen
  */
 
@@ -27,11 +27,14 @@
 #ifndef AUTOGEN_HDR_H
 #define AUTOGEN_HDR_H
 
-#include "compat/compat.h"
-#include "autoopts/autoopts.h"
 #include "agUtils.h"
+#include "compat/compat.h"
+#include "expr.h"
+#include "autoopts/autoopts.h"
 #include "streqv.h"
 
+#include "cgi-fsm.h"
+
 #define STATE_TABLE           /* set up `atexit' and load Guile   */  \
     _State_( INIT )           /* processing command line options  */  \
     _State_( OPTIONS )        /* Loading guile at option time     */  \
@@ -89,7 +92,7 @@ typedef tHdlrProc* tpHdlrProc;
 #include "functions.h"
 
 #define TEMPLATE_REVISION     1
-#define TEMPLATE_MAGIC_MARKER {{'A', 'G', 'L', 'B'}, \
+#define TEMPLATE_MAGIC_MARKER {{{'A', 'G', 'L', 'B'}}, \
                                TEMPLATE_REVISION, FUNCTION_CKSUM }
 
 struct template_lib_marker {
@@ -162,7 +165,7 @@ typedef enum {
 
 typedef struct def_stack tDefStack;
 struct def_stack {
-	tDefEntry* pDefs;        /* ptr to current def set     */
+    tDefEntry* pDefs;        /* ptr to current def set     */
     tDefStack* pPrev;        /* ptr to previous def set    */
 };
 
@@ -198,7 +201,7 @@ struct outSpec {
 #define FPF_NOCHMOD    0x0010  /* do not chmod(2) file    */
 
 struct fpStack {
-	int         flags;
+    int         flags;
     tFpStack*   pPrev;
     FILE*       pFile;
     char*       pzOutName;
@@ -257,6 +260,7 @@ MODE char*       pzCurStart       VALUE( NULL );
 MODE uintptr_t   curStartOff      VALUE( 0 );
 MODE tForInfo    forInfo          VALUE( { 0 } );
 MODE FILE*       pfTrace          VALUE( NULL );
+MODE char*       pzTmpStderr      VALUE( NULL );
 
 MODE tCC*        serverArgs[2]    VALUE( { NULL } );
 MODE tCC*        pzShellProgram   VALUE( NULL );
@@ -279,6 +283,7 @@ MODE tCC*        pzShellProgram   VALUE( NULL );
 MODE tDefStack   currDefCtx       VALUE( { NULL } );
 MODE tDefStack   rootDefCtx       VALUE( { NULL } );
 MODE tTemplate*  pCurTemplate     VALUE( NULL );
+MODE tCC*        pzLastScheme     VALUE( NULL );
 
 /*
  *  Current Macro
@@ -326,20 +331,10 @@ MKSTRING( ShDone,    "ShElL-OuTpUt-HaS-bEeN-cOmPlEtEd" );
 MKSTRING( NotStr,    "ERROR: %s is not a string\n" );
 MKSTRING( DevNull,   "/dev/null" );
 MKSTRING( ShellEnv,  "SHELL" );
+MKSTRING( Nil,       "" );
 
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *
- *  MEMORY DEBUGGING
- */
-#ifdef MEMDEBUG
-
-   extern void  unloadTemplate( tTemplate* pT );
-   extern void  unloadDefs( void );
-
-#else
-#  define unloadTemplate(pt)
-#  define unloadDefs()
-#endif
+extern void unloadTemplate( tTemplate* pT );
+extern void unloadDefs( void );
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
@@ -351,7 +346,7 @@ size_t strlcpy( char* dest, const char* src, size_t n );
 
 #include "proto.h"
 
-#ifdef DEBUG
+#ifdef DEBUG_ENABLED
 # define AG_ABEND(s)  ag_abend_at(s,__FILE__,__LINE__)
 #else
 # define AG_ABEND(s)  ag_abend(s)
@@ -369,10 +364,25 @@ static inline char* ag_scm2zchars( SCM s, tCC* type )
     return SCM_CHARS(s);
 }
 
+static inline SCM ag_eval( tCC* pzStr )
+{
+    SCM res;
+    tCC* pzSaveScheme = pzLastScheme; /* Watch for nested calls */
+    pzLastScheme = pzStr;
+
+    res = ag_scm_c_eval_string_from_file_line(
+        pzStr, pCurTemplate->pzFileName, pCurMacro->lineNo );
+
+    pzLastScheme = pzSaveScheme;
+    return res;
+}
+
 #endif /* AUTOGEN_HDR */
 /*
  * Local Variables:
- * c-file-style: "Stroustrup"
+ * mode: C
+ * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of autogen.h */
+ * end of agen5/autogen.h */
