@@ -1,7 +1,7 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (cgi-fsm.c)
  *  
- *  It has been AutoGen-ed  Saturday March 15, 2003 at 10:03:36 AM PST
+ *  It has been AutoGen-ed  Sunday June  1, 2003 at 11:40:46 AM PDT
  *  From the definitions    cgi.def
  *  and the template file   fsm
  *
@@ -45,29 +45,9 @@
  */
 /* START === USER HEADERS === DO NOT CHANGE THIS COMMENT */
 
-/*
- *  AutoGen copyright 1992-2002 Bruce Korb
- *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
- *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
- */
-
 #include "autogen.h"
-#ifndef DEBUG_FSM
-#  undef DEBUG_ENABLED
+#ifdef DEBUG_ENABLED
+#  define DEBUG
 #endif
 
 /* END   === USER HEADERS === DO NOT CHANGE THIS COMMENT */
@@ -209,9 +189,11 @@ cgi_run_fsm(
         /* START == FIND TRANSITION == DO NOT CHANGE THIS COMMENT */
 
         char  curCh;
-        if (--inlen < 0)
+        if (--inlen < 0) {
             trans_evt = CGI_EV_END;
-        else {
+            curCh = NUL;
+
+        } else {
             if (outlen < 4) {
                 strcpy( pzOut, "output space exhausted\n" );
                 return CGI_ST_INVALID;
