@@ -1,6 +1,6 @@
 
 /*
- *  $Id: defReduce.c,v 1.22 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: defReduce.c,v 1.27 2003/04/29 01:42:37 bkorb Exp $
  *  Parse Reduction processing routines
  */
 
@@ -30,43 +30,13 @@ typedef struct {
     char*   entries[1];
 } tList;
 
-#include "autogen.h"
-
 STATIC tDefEntry* pFreeEntryList = NULL;
 STATIC void*      pAllocList     = NULL;
 
-#define ENTRY_ALLOC_CT     (4092 / sizeof(tDefEntry))
-#define ENTRY_ALLOC_SIZE   ((ENTRY_ALLOC_CT * sizeof( tDefEntry )) + 4)
-
-
-#ifdef MEMDEBUG
-    void
-unloadDefs( void )
-{
-    /*
-     *  Free up the definitions data
-     */
-    for (;;) {
-        tScanCtx* p = pDoneCtx->pCtx;
-        AGFREE( (void*)pDoneCtx );
-        pDoneCtx = p;
-        if (p == NULL)
-            break;
-    }
-
-    for (;;) {
-        void* p = *(void**)pAllocList;
-        AGFREE( pAllocList );
-        if (p == NULL)
-            break;
-        pAllocList = p;
-    }
-
-    if (forInfo.fi_data != NULL)
-        AGFREE( (void*)forInfo.fi_data );
-}
-#endif
-
+#define ENTRY_SPACE        (4096 - sizeof(void*))
+#define ENTRY_ALLOC_CT     (ENTRY_SPACE / sizeof(tDefEntry))
+#define ENTRY_ALLOC_SIZE   \
+    ((ENTRY_ALLOC_CT * sizeof( tDefEntry )) + sizeof(void*))
 
 EXPORT void
 freeEntry( tDefEntry* pDE )
@@ -323,7 +293,7 @@ identify( YYSTYPE template )
 {
     /*
      *  Allow this routine to be called multiple times.
-     *  This may happen if we #include another definition file.
+     *  This may happen if we include another definition file.
      */
     if (pzTemplFileName == NULL) {
 
@@ -336,7 +306,9 @@ identify( YYSTYPE template )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of defReduce.c */
+ * end of agen5/defReduce.c */
