@@ -2,7 +2,7 @@
 /*  -*- Mode: C -*-
  *
  *  expMake.c
- *  $Id: expMake.c,v 1.4 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: expMake.c,v 1.7 2003/04/21 03:27:49 bkorb Exp $
  *  This module implements Makefile construction functions.
  */
 
@@ -26,9 +26,6 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#include "expr.h"
-#include "autogen.h"
-
 /*=gfunc makefile_script
  *
  * what:  create makefile script
@@ -268,7 +265,9 @@ ag_scm_makefile_script( SCM text )
 
 /*
  * Local Variables:
- * c-file-style: "Stroustrup"
+ * mode: C
+ * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of expMake.c */
+ * end of agen5/expMake.c */
