@@ -1,6 +1,6 @@
 
 /*
- *  $Id: expOutput.c,v 1.27 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: expOutput.c,v 1.34 2003/05/24 02:40:43 bkorb Exp $
  *
  *  This module implements the output file manipulation function
  */
@@ -25,12 +25,6 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#include <time.h>
-#include <utime.h>
-
-#include "autogen.h"
-#include "expr.h"
-
 #ifndef S_IAMB
 /*
  *  Access Mask Bits (3 special plus RWX for User Group & Others (9))
@@ -104,7 +98,7 @@ addWriteAccess( char* pzFileName )
  *  output files.  Use the @code{(error "0")} scheme function instead.
  *  @xref{output controls}.
 =*/
-    SCM
+SCM
 ag_scm_out_delete( void )
 {
     tSCC zSkipMsg[] = "NOTE:  skipping file '%s'\n";
@@ -130,7 +124,7 @@ ag_scm_out_delete( void )
  *         file from being deleted.  It @i{may}, however, be used on the
  *         root output file.
 =*/
-    SCM
+SCM
 ag_scm_out_move( SCM new_file )
 {
     size_t sz = SCM_LENGTH( new_file );
@@ -160,7 +154,7 @@ ag_scm_out_move( SCM new_file )
  *  the argument should be @code{#t} and the contents of the file
  *  are returned by the function.
 =*/
-    SCM
+SCM
 ag_scm_out_pop( SCM ret_contents )
 {
     SCM res = SCM_UNDEFINED;
@@ -197,12 +191,9 @@ ag_scm_out_pop( SCM ret_contents )
  *  change the tag every time you suspend output to a file, because the
  *  tag names are forgotten as soon as the file has been "resumed".
 =*/
-    SCM
+SCM
 ag_scm_out_suspend( SCM suspName )
 {
-    SCM res = SCM_UNDEFINED;
-    tCC* pzSuspName = ag_scm2zchars( suspName, "suspend name" );
-
     if (pCurFp->pPrev == NULL)
         AG_ABEND( "ERROR:  Cannot pop output with no output pushed" );
 
@@ -224,7 +215,7 @@ ag_scm_out_suspend( SCM suspName )
     pCurFp = pCurFp->pPrev;
     outputDepth--;
 
-    return res;
+    return SCM_UNDEFINED;
 }
 
 
@@ -237,7 +228,7 @@ ag_scm_out_suspend( SCM suspName )
  *  current again.  That output must have been suspended with the same tag
  *  name given to this routine as its argument.
 =*/
-    SCM
+SCM
 ag_scm_out_resume( SCM suspName )
 {
     int  ix  = 0;
@@ -247,7 +238,7 @@ ag_scm_out_resume( SCM suspName )
         if (strcmp( pSuspended[ ix ].pzSuspendName, pzName ) == 0) {
             pSuspended[ ix ].pOutDesc->pPrev = pCurFp;
             pCurFp = pSuspended[ ix ].pOutDesc;
-            free( (void*)pSuspended[ ix ].pzSuspendName ); /* Guile allocation */
+            free( (void*)pSuspended[ ix ].pzSuspendName ); /* Guile alloc */
             if (ix < --suspendCt)
                 pSuspended[ ix ] = pSuspended[ suspendCt ];
             ++outputDepth;
@@ -271,7 +262,7 @@ ag_scm_out_resume( SCM suspName )
  *  Identical to @code{push-new}, except the contents are @strong{not}
  *  purged, but appended to.  @xref{output controls}.
 =*/
-    SCM
+SCM
 ag_scm_out_push_add( SCM new_file )
 {
     tFpStack* p;
@@ -321,7 +312,7 @@ ag_scm_out_push_add( SCM new_file )
  *  it is closed.
  *  @xref{output controls}.
 =*/
-    SCM
+SCM
 ag_scm_out_push_new( SCM new_file )
 {
     tFpStack* p;
@@ -362,7 +353,8 @@ ag_scm_out_push_new( SCM new_file )
         if (tmpfd < 0)
             AG_ABEND( aprf( "failed to create temp file from `%s'", pzTemp ));
 
-        p->pFile  = fdopen( tmpfd, "a" FOPEN_BINARY_FLAG "+" );
+        p->pFile  = fopen( pzNewFile, "w" FOPEN_BINARY_FLAG "+" );
+        close( tmpfd );
     }
 
     if (p->pFile == NULL)
@@ -388,7 +380,7 @@ ag_scm_out_push_new( SCM new_file )
  *  you may not pop the base level output file, but you may
  *  @code{switch} it.  @xref{output controls}.
 =*/
-    SCM
+SCM
 ag_scm_out_switch( SCM new_file )
 {
     struct utimbuf tbuf;
@@ -418,7 +410,7 @@ ag_scm_out_switch( SCM new_file )
      *  and try to ensure nothing is in the way.
      */
     unlink( pzNewFile );
-    if (   freopen( pzNewFile, "w" FOPEN_BINARY_FLAG, pCurFp->pFile )
+    if (   freopen( pzNewFile, "w" FOPEN_BINARY_FLAG "+", pCurFp->pFile )
         != pCurFp->pFile)
 
         AG_ABEND( aprf( zCannot, errno, "freopen", pzNewFile,
@@ -442,7 +434,7 @@ ag_scm_out_switch( SCM new_file )
  * doc:  Returns the depth of the output file stack.
  *       @xref{output controls}.
 =*/
-    SCM
+SCM
 ag_scm_out_depth( void )
 {
     return gh_int2scm( outputDepth );
@@ -457,7 +449,7 @@ ag_scm_out_depth( void )
  *       a real output file name is found.
  *       @xref{output controls}.
 =*/
-    SCM
+SCM
 ag_scm_out_name( void )
 {
     tFpStack* p = pCurFp;
@@ -465,9 +457,45 @@ ag_scm_out_name( void )
     return gh_str02scm( p->pzOutName );
 }
 
+
+/*=gfunc out_line
+ *
+ * what: output file line number
+ * doc:  Returns the current line number of the output file.
+ *       It rewinds and reads the file to count newlines.
+=*/
+SCM
+ag_scm_out_line( void )
+{
+    int lineNum = 1;
+
+    do {
+        long svpos = ftell( pCurFp->pFile );
+        long pos   = svpos;
+
+        if (pos == 0)
+            break;
+
+        rewind( pCurFp->pFile );
+        do {
+            int ich = fgetc( pCurFp->pFile );
+            unsigned char ch = ich;
+            if (ich < 0)
+                break;
+            if (ch == (unsigned char)'\n')
+                lineNum++;
+        } while (--pos > 0);
+        fseek( pCurFp->pFile, svpos, SEEK_SET );
+    } while(0);
+
+    return gh_int2scm( lineNum );
+}
+
 /*
  * Local Variables:
- * c-file-style: "Stroustrup"
+ * mode: C
+ * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of expOutput.c */
+ * end of agen5/expOutput.c */
