@@ -1,6 +1,6 @@
 
 /*
- *  $Id: expPrint.c,v 1.29 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: expPrint.c,v 1.36 2003/05/31 22:59:15 bkorb Exp $
  *
  *  The following code is necessary because the user can give us
  *  a printf format requiring a string pointer yet fail to provide
@@ -29,20 +29,9 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#include <signal.h>
-#include <compat/compat.h>
-
-#ifndef HAVE_STRSIGNAL
-#  include <compat/strsignal.c>
-#endif
-
-#include "expr.h"
-#include "autogen.h"
-
 STATIC sigjmp_buf printJumpEnv;
-STATIC void    printFault( int sig );
-STATIC size_t safePrintf( char* pzBuf, size_t bufSize,
-                          char* pzFmt, void** argV );
+STATIC void   printFault( int sig );
+STATIC ssize_t safePrintf( char** pzBuf, char* pzFmt, void** argV );
 tSCC pzFormatName[] = "format";
 
 STATIC void
@@ -52,55 +41,58 @@ printFault( int sig )
 }
 
 
-STATIC size_t
-safePrintf( char* pzBuf, size_t bufSize, char* pzFmt, void** argV )
+STATIC ssize_t
+safePrintf( char** ppzBuf, char* pzFmt, void** argV )
 {
     tSCC zBadArgs[]  = "Bad args to sprintf";
     tSCC zBadFmt[]   = "%s ERROR:  %s processing printf format:\n\t%s\n";
 
-    size_t printSize;
-    int    faultType;
-
-    struct sigaction  sa;
     struct sigaction  saSave1;
     struct sigaction  saSave2;
 
-    sa.sa_handler = printFault;
-    sa.sa_flags   = 0;
-    sigemptyset( &sa.sa_mask );
+    {
+        struct sigaction  sa;
+        sa.sa_handler = printFault;
+        sa.sa_flags   = 0;
+        sigemptyset( &sa.sa_mask );
 
-    sigaction( SIGBUS,  &sa, &saSave1 );
-    sigaction( SIGSEGV, &sa, &saSave2 );
+        sigaction( SIGBUS,  &sa, &saSave1 );
+        sigaction( SIGSEGV, &sa, &saSave2 );
+    }
 
     /*
      *  IF the sprintfv call below is going to address fault,
      *  THEN ...
      */
-    if (faultType = sigsetjmp( printJumpEnv, 0 ),
-        faultType != 0) {
+    {
+        int faultType = sigsetjmp( printJumpEnv, 0 );
+        if (faultType != 0) {
 #ifndef HAVE_STRSIGNAL
-        extern char* strsignal PARAMS((int signo));
+            extern char* strsignal(int signo);
 #endif
-        /*
-         *  IF the fprintf command in the then clause has not failed yet,
-         *  THEN perform that fprintf
-         */
-        if (sigsetjmp( printJumpEnv, 0 ) == 0)
-            fprintf( pfTrace, zBadFmt, pzProg, strsignal( faultType ), pzFmt );
+            /*
+             *  IF the fprintf command in the then clause has not failed yet,
+             *  THEN perform that fprintf
+             */
+            if (sigsetjmp( printJumpEnv, 0 ) == 0)
+                fprintf(pfTrace, zBadFmt, pzProg, strsignal( faultType ), pzFmt);
 
-        /*
-         *  The "sprintfv" command below faulted, so we exit
-         */
-        AG_ABEND( zBadArgs );
+            /*
+             *  The "sprintfv" command below faulted, so we exit
+             */
+            AG_ABEND( zBadArgs );
+        }
     }
 
-    printSize = snprintfv( pzBuf, bufSize, pzFmt, (void*)argV );
-    if ((printSize & ~0xFFFFFF) != 0)
-        AG_ABEND( aprf( "snprintf returned 0x%08X\n", printSize ));
+    {
+        size_t printSize = asprintfv( ppzBuf, pzFmt, (void*)argV );
+        if ((printSize & ~0xFFFFFF) != 0)
+            AG_ABEND( aprf( "asprintfv returned 0x%08X\n", printSize ));
 
-    sigaction( SIGBUS,  &saSave1, NULL );
-    sigaction( SIGSEGV, &saSave2, NULL );
-    return printSize;
+        sigaction( SIGBUS,  &saSave1, NULL );
+        sigaction( SIGSEGV, &saSave2, NULL );
+        return printSize;
+    }
 }
 
 
@@ -108,25 +100,15 @@ EXPORT SCM
 run_printf( char* pzFmt, int len, SCM alist )
 {
     SCM     res;
+    void*   args[8];
     void**  arglist;
     void**  argp;
-    char*   pzBuf;
-    size_t  bfSize = (len * 128) + strlen( pzFmt );
 
-    void**  freelist;
-    void**  freep;
-
-    /*
-     *  Allocate everything we need at once.  Round up to next 4096 bytes.
-     *  Most likely, we allocate and free a page every time.
-     */
-    bfSize += 2 * len * sizeof( void* ) + 0x100F;
-    bfSize &= ~0x0FFF;
-
-    arglist  = argp  = (void**)AGALOC( bfSize, "sprintf buffer" );
-    freelist = freep = arglist + len;
-    pzBuf    = (char*)(freelist + len);
-    bfSize  -= 2 * len * sizeof( void* );
+    if (len < 8)
+        arglist = argp = args;
+    else
+        arglist =
+        argp    = (void**)malloc( (len+1) * sizeof(void*));
 
     while (len-- > 0) {
         SCM  car = SCM_CAR( alist );
@@ -155,7 +137,7 @@ run_printf( char* pzFmt, int len, SCM alist )
 
         case GH_TYPE_SYMBOL:
         case GH_TYPE_STRING:
-            *(freep++) = *(argp++) = (void*)gh_scm2newstr( car, NULL );
+            *(argp++) = (void*)ag_scm2zchars( car, "printf str" );
             break;
 
         case GH_TYPE_PROCEDURE:
@@ -173,13 +155,16 @@ run_printf( char* pzFmt, int len, SCM alist )
      *  Do the formatting and allocate a new SCM to hold the result.
      *  Free up any allocations made by ``gh_scm2newstr''
      */
-    bfSize = safePrintf( pzBuf, bfSize, pzFmt, arglist );
-    res = gh_str2scm( pzBuf, bfSize );
+    {
+        char*   pzBuf;
+        ssize_t bfSize = safePrintf( &pzBuf, pzFmt, arglist );
+        res = gh_str2scm( pzBuf, bfSize );
+        free( pzBuf );
+    }
 
-    while (freelist < freep)
-        free( *(freelist++) );
+    if (arglist != args)
+        AGFREE( (void*)arglist );
 
-    AGFREE( (void*)arglist );
     return res;
 }
 
@@ -194,7 +179,7 @@ run_printf( char* pzFmt, int len, SCM alist )
  *
  * doc:  Format a string using arguments from the alist.
 =*/
-    SCM
+SCM
 ag_scm_sprintf( SCM fmt, SCM alist )
 {
     int   list_len = scm_ilength( alist );
@@ -220,7 +205,7 @@ ag_scm_sprintf( SCM fmt, SCM alist )
  *       output.  Use this to print information messages to a template user.
  *       Use ``(sprintf ...)'' to add text to your document.
 =*/
-    SCM
+SCM
 ag_scm_printf( SCM fmt, SCM alist )
 {
     int   list_len = scm_ilength( alist );
@@ -244,7 +229,7 @@ ag_scm_printf( SCM fmt, SCM alist )
  *       Write to a specified port.  The result will NOT appear in your
  *       output.  Use this to print information messages to a template user.
 =*/
-    SCM
+SCM
 ag_scm_fprintf( SCM port, SCM fmt, SCM alist )
 {
     int   list_len = scm_ilength( alist );
@@ -293,7 +278,6 @@ ag_scm_hide_email( SCM display, SCM eaddr )
 
     {
         char* pz = SCM_CHARS( res );
-        char* p  = pz;
 
         strcpy( pz, zStrt );
         pz += sizeof( zStrt ) - 1;
@@ -326,7 +310,7 @@ ag_scm_hide_email( SCM display, SCM eaddr )
  *         "arguments to provide for in the macro. e.g. for this extraction\n"
  *         "text:\n"
  *         "@example\n\n"
- *         " /*=fumble bumble\n"
+ *         " /" "*=fumble bumble\n"
  *         "  * fmt: 'stumble %s: %d\\n'\n"
  *         " =*" "/\n"
  *         "@end example\n\n"
@@ -338,7 +322,7 @@ ag_scm_hide_email( SCM display, SCM eaddr )
  *         "@noindent\n"
  *         "You can do this by knowing that the format needs two arguments.\n"
 =*/
-    SCM
+SCM
 ag_scm_format_arg_count( SCM fmt )
 {
     char* pzFmt = ag_scm2zchars( fmt, pzFormatName );
@@ -357,7 +341,9 @@ ag_scm_format_arg_count( SCM fmt )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of expPrint.c */
+ * end of agen5/expPrint.c */
