@@ -1,13 +1,13 @@
 
 /*
  *  expString.c
- *  $Id: expString.c,v 1.47 2002/09/29 00:14:18 bkorb Exp $
+ *  $Id: expString.c,v 1.53 2003/05/02 00:54:07 bkorb Exp $
  *  This module implements expression functions that
  *  manipulate string values.
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -26,16 +26,6 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#include <string.h>
-
-#include "expr.h"
-#include "autogen.h"
-
-#ifndef HAVE_STRFTIME
-#  include "compat/strftime.c"
-#endif
-
-
 STATIC SCM
 makeString( tCC*    pzText,
             tCC*    pzNewLine,
@@ -427,7 +417,7 @@ do_multi_subs(
  * doc:  Return SCM_BOOL_T if the first argument string is found
  *      in one of the entries in the second (list-of-strings) argument.
 =*/
-    SCM
+SCM
 ag_scm_in_p( SCM obj, SCM list )
 {
     int   len;
@@ -496,7 +486,7 @@ ag_scm_in_p( SCM obj, SCM list )
  *       The list may contain nested lists, partly because you
  *       cannot always control that.
 =*/
-    SCM
+SCM
 ag_scm_join( SCM sep, SCM list )
 {
     int        l_len, sv_l_len;
@@ -606,7 +596,7 @@ ag_scm_join( SCM sep, SCM list )
  *  # lines
  *  @end example
 =*/
-    SCM
+SCM
 ag_scm_prefix( SCM prefix, SCM text )
 {
     char*    pzPfx;
@@ -688,7 +678,7 @@ ag_scm_prefix( SCM prefix, SCM text )
  *  @code{cd} to the original directory is always issued before
  *  the new command is issued.
 =*/
-    SCM
+SCM
 ag_scm_shell( SCM cmd )
 {
     if (! gh_string_p( cmd ))
@@ -713,7 +703,7 @@ ag_scm_shell( SCM cmd )
  * doc:  Format a string using arguments from the alist,
  *       then send the result to the shell for interpretation.
 =*/
-    SCM
+SCM
 ag_scm_shellf( SCM fmt, SCM alist )
 {
     int   len = scm_ilength( alist );
@@ -753,7 +743,7 @@ ag_scm_shellf( SCM fmt, SCM alist )
  *  non-printing characters.  This routine works for most reasonably
  *  conventional ASCII strings.
 =*/
-    SCM
+SCM
 ag_scm_raw_shell_str( SCM obj )
 {
     static const char zQ[] = "'\\''";
@@ -764,7 +754,7 @@ ag_scm_raw_shell_str( SCM obj )
     SCM        res;
 
     pzDta   = ag_scm2zchars( obj, "AG Object" );
-    dtaSize = strlen( pzDta ) + 3;
+    dtaSize = SCM_LENGTH( obj ) + 3;
     pz = pzDta-1;
     for (;;) {
         pz = strchr( pz+1, '\'' );
@@ -784,7 +774,7 @@ ag_scm_raw_shell_str( SCM obj )
             goto loopDone;
 
         case '\'':
-            strcpy( pz-1, zQ );
+            strcpy( pz, zQ+1 );
             pz += STRSIZE( zQ ) - 1;
         }
     } loopDone:;
@@ -836,20 +826,20 @@ ag_scm_raw_shell_str( SCM obj )
  *  @code{raw-shell-str}, @code{shell-str} and @code{sub-shell-str} functions.
  *
  *  @example
- *  foo[0]       = 'foo' "foo" `foo` $foo
- *  raw-shell-str: ''\''foo'\'' "foo" `foo` $foo'
- *  shell-str:     "'foo' \"foo\" `foo` $foo"
- *  sub-shell-str: `'foo' "foo" \`foo\` $foo`
+ *  foo[0]           'foo' "foo" `foo` $foo
+ *  raw-shell-str -> ''\''foo'\'' "foo" `foo` $foo'
+ *  shell-str     -> "'foo' \"foo\" `foo` $foo"
+ *  sub-shell-str -> `'foo' "foo" \`foo\` $foo`
  *
- *  foo[1]       = \'bar\' \"bar\" \`bar\` \$bar
- *  raw-shell-str: '\'\''bar\'\'' \"bar\" \`bar\` \$bar'
- *  shell-str:     "\\'bar\\' \\\"bar\\\" \`bar\` \$bar"
- *  sub-shell-str: `\\'bar\\' \"bar\" \\\`bar\\\` \$bar`
+ *  foo[1]           \'bar\' \"bar\" \`bar\` \$bar
+ *  raw-shell-str -> '\'\''bar\'\'' \"bar\" \`bar\` \$bar'
+ *  shell-str     -> "\\'bar\\' \\\"bar\\\" \`bar\` \$bar"
+ *  sub-shell-str -> `\\'bar\\' \"bar\" \\\`bar\\\` \$bar`
  *
- *  foo[2]       = \\'BAZ\\' \\"BAZ\\" \\`BAZ\\` \\$BAZ
- *  raw-shell-str: '\\'\''BAZ\\'\'' \\"BAZ\\" \\`BAZ\\` \\$BAZ'
- *  shell-str:     "\\\\'BAZ\\\\' \\\\\"BAZ\\\\\" \\\`BAZ\\\` \\\$BAZ"
- *  sub-shell-str: `\\\\'BAZ\\\\' \\\"BAZ\\\" \\\\\`BAZ\\\\\` \\\$BAZ`
+ *  foo[2]           \\'BAZ\\' \\"BAZ\\" \\`BAZ\\` \\$BAZ
+ *  raw-shell-str -> '\\'\''BAZ\\'\'' \\"BAZ\\" \\`BAZ\\` \\$BAZ'
+ *  shell-str     -> "\\\\'BAZ\\\\' \\\\\"BAZ\\\\\" \\\`BAZ\\\` \\\$BAZ"
+ *  sub-shell-str -> `\\\\'BAZ\\\\' \\\"BAZ\\\" \\\\\`BAZ\\\\\` \\\$BAZ`
  *  @end example
  *
  *  There should be four, three, five and three backslashes for the four
@@ -859,7 +849,7 @@ ag_scm_raw_shell_str( SCM obj )
  *  backslashes in front of the dollar signs.  It goes from zero to one to
  *  three for the "cooked" string examples.
 =*/
-    SCM
+SCM
 ag_scm_shell_str( SCM obj )
 {
     return shell_stringify( obj, '"' );
@@ -877,7 +867,7 @@ ag_scm_shell_str( SCM obj )
  *   that the quoting character is @code{`} and the "leave the escape alone"
  *   character is @code{"}.
 =*/
-    SCM
+SCM
 ag_scm_sub_shell_str( SCM obj )
 {
     return shell_stringify( obj, '`' );
@@ -893,7 +883,7 @@ ag_scm_sub_shell_str( SCM obj )
  * doc:  Create a scheme list of all the strings that are associated
  *       with a name.  They must all be text values or we choke.
 =*/
-    SCM
+SCM
 ag_scm_stack( SCM obj )
 {
     SCM   res;
@@ -940,7 +930,7 @@ ag_scm_stack( SCM obj )
  *  replaced with escape sequences.  New-lines are replaced with a
  *  backslash-n-backslash and newline sequence,
 =*/
-    SCM
+SCM
 ag_scm_kr_string( SCM str )
 {
     tSCC zNewLine[] = "\\n\\\n";
@@ -969,7 +959,7 @@ ag_scm_kr_string( SCM str )
  *  A K&R compiler will choke.  Use @code{kr-string} for that compiler.
  *
 =*/
-    SCM
+SCM
 ag_scm_c_string( SCM str )
 {
     tSCC zNewLine[] = "\\n\"\n       \"";
@@ -996,7 +986,7 @@ ag_scm_c_string( SCM str )
  *      It is too bad this little program has so many different
  *      and incompatible implementations!
 =*/
-    SCM
+SCM
 ag_scm_string_tr_x( SCM str, SCM from_xform, SCM to_xform )
 {
     {
@@ -1064,7 +1054,7 @@ ag_scm_string_tr_x( SCM str, SCM from_xform, SCM to_xform )
  * doc: This is identical to @code{string-tr!}, except that it does not
  *      over-write the previous value.
 =*/
-    SCM
+SCM
 ag_scm_string_tr( SCM Str, SCM From, SCM To )
 {
     scm_sizet lenz  = SCM_LENGTH( Str );
@@ -1095,7 +1085,7 @@ ag_scm_string_tr( SCM Str, SCM From, SCM To )
  *      ("&amp;" "&lt;" "&gt;"))
  * @end example
 =*/
-    SCM
+SCM
 ag_scm_string_substitute( SCM Str, SCM Match, SCM Repl )
 {
     tCC*       pzStr;
@@ -1128,7 +1118,9 @@ ag_scm_string_substitute( SCM Str, SCM Match, SCM Repl )
 
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of expString.c */
+ * end of agen5/expString.c */
