@@ -1,6 +1,6 @@
 
 /*
- *  $Id: funcDef.c,v 1.52 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: funcDef.c,v 1.57 2003/05/17 01:27:26 bkorb Exp $
  *
  *  This module implements the DEFINE text function.
  */
@@ -24,14 +24,6 @@
  *             59 Temple Place - Suite 330,
  *             Boston,  MA  02111-1307, USA.
  */
-#ifndef DEFINE_LOAD_FUNCTIONS
-
-#include <guile/gh.h>
-
-#include "expr.h"
-#include "autogen.h"
-
-tSCC zNil[] = "";
 
 typedef int (tCmpProc)( const void*, const void* );
 
@@ -41,9 +33,8 @@ struct def_list {
     char*      pzExpr;
 };
 
-tSCC  zNoResolution[] = "Could not resolve macro name: ``%s''";
+tSCC zNoResolution[] = "Could not resolve macro name: ``%s''";
 tSCC zTplInvoked[] = "Template macro %s invoked with %d args\n";
-#endif /* not defined DEFINE_LOAD_FUNCTIONS */
 
 STATIC tDefList* linkTwins( tDefList* pDL, tDefList* pNext, int* pCt );
 
@@ -346,7 +337,6 @@ prepInvokeArgs( tMacro* pMac )
 }
 
 
-#ifndef DEFINE_LOAD_FUNCTIONS
 #ifdef DEBUG_ENABLED
 /*=macfunc DEBUG, ifdef DEBUG_ENABLED
  *
@@ -357,7 +347,7 @@ prepInvokeArgs( tMacro* pMac )
  *      a breakpoint on the #n case element below and step through
  *      the processing of interesting parts of your template.
 =*/
-    tMacro*
+tMacro*
 mFunc_Debug( tTemplate* pT, tMacro* pMac )
 {
     static int dummy = 0;
@@ -438,7 +428,7 @@ build_defs( int defCt, tDefList* pList )
                 fprintf( pfTrace, "Scheme eval for arg %d:\n\t`%s'\n",
                          pCurMacro->sibIndex - defCt, pList->pzExpr );
             }
-            res = gh_eval_str( pList->pzExpr );
+            res = ag_eval( pList->pzExpr );
 
             if (gh_string_p( res )) {
                 AGDUPSTR( pList->de.pzValue, ag_scm2zchars( res, "eval res" ),
@@ -526,14 +516,11 @@ build_defs( int defCt, tDefList* pList )
  *
  *  This routine runs the invocation.
  */
-    tMacro*
+tMacro*
 mFunc_Define( tTemplate* pT, tMacro* pMac )
 {
     tDefList*   pList  = (tDefList*)pMac->res;
     int         defCt  = pMac->sibIndex;
-    SCM         res;
-    tDefEntry*  pDefs;
-    tDefStack*  pStack;
     tDefStack   stack;
 
     pT = (tTemplate*)pMac->funcPrivate;
@@ -605,7 +592,7 @@ mFunc_Define( tTemplate* pT, tMacro* pMac )
  *  the first time the macro is processed and evaluated again every
  *  time the macro is evaluated.
 =*/
-    tMacro*
+tMacro*
 mFunc_Invoke( tTemplate* pT, tMacro* pMac )
 {
     char* pzText;
@@ -656,7 +643,6 @@ mFunc_Invoke( tTemplate* pT, tMacro* pMac )
 
     return mFunc_Define( pT, pMac );
 }
-#endif /* DEFINE_LOAD_FUNCTIONS not defined */
 
 
 /* Load Debug
@@ -664,14 +650,14 @@ mFunc_Invoke( tTemplate* pT, tMacro* pMac )
  *  what:   Loads the debug function so you can set breakpoints
  *          at load time, too :-)
 =*/
-    tMacro*
+tMacro*
 mLoad_Debug( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
     return mLoad_Unknown( pT, pMac, ppzScan );
 }
 
 
-    tMacro*
+tMacro*
 mLoad_Define( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
     tSCC         zNameNeeded[] = "DEFINE requires a name";
@@ -803,7 +789,9 @@ mLoad_Define( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of funcDef.c */
+ * end of agen5/funcDef.c */
