@@ -153,7 +153,7 @@ extern tpLoadProc   apLoadProc[ 20 ];
 extern tpLoadProc*  papLoadProc;
 #endif /* AUTOGEN_FUNCTIONS_H */
 
-#ifdef LOAD_FUNCTIONS  /* tpParse.c use only * * * * * * * * * * * * * * * *
+#ifdef DEFINING /* tpParse.c use only * * * * * * * * * * * * * * * *
  *
  *  Pointers for the load processing (template scanning phase)
  */
@@ -275,7 +275,7 @@ const char*  apzFuncNames[ FUNC_CT ] = {
     "FOR",      "IF",       "INCLUDE",  "INVOKE",   "SELECT",   "Text",
     "Unknown",  "WHILE"
 };
-#endif /* LOAD_FUNCTIONS */
+#endif /* DEFINING */
 
 #define FUNCTION_CKSUM 7851
 
@@ -292,7 +292,7 @@ const char*  apzFuncNames[ FUNC_CT ] = {
 #include "functions.c"
 #endif /* DEFINE_LOAD_FUNCTIONS */
 
-#ifdef HANDLE_FUNCTIONS /* tpProcess.c use only * * * * * * * * * * * * * *
+#ifdef DEFINING /* tpProcess.c use only * * * * * * * * * * * * * *
 
  *  Template Processing Function Table
  *
@@ -322,10 +322,12 @@ static tpHdlrProc  apHdlrProc[ FUNC_CT ] = {
     /* WHILE     */ &mFunc_While
 };
 
-#endif /* HANDLE_FUNCTIONS */
+#endif /* DEFINING */
 /*
  * Local Variables:
- * c-file-style: "Stroustrup"
+ * mode: C
+ * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of functions.h */
+ * end of agen5/functions.h */
