@@ -1,6 +1,6 @@
 
 /*
- *  $Id: loadPseudo.c,v 1.24 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: loadPseudo.c,v 1.30 2003/05/31 22:59:15 bkorb Exp $
  *
  *  This module processes the "pseudo" macro
  */
@@ -25,15 +25,7 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#include <sys/types.h>
-#include <sys/param.h>
-#include <sys/mman.h>
-#include <fcntl.h>
-
-#include "autogen.h"
-
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *
+/*
  *  loadPseudoMacro
  *
  *  Find the start and end macro markers.  In btween we must find the
@@ -53,16 +45,24 @@ tSCC zTpName[] = "template";
  *  Process a scheme specification
  */
 STATIC tCC*
-doSchemeExpr( tCC* pzData, tCC* pzFileName, int lineNo )
+doSchemeExpr( tCC* pzData, tCC* pzFileName )
 {
-    char* pzEnd = (char*)pzData + strlen( pzData );
-    char  ch;
+    char*   pzEnd = (char*)pzData + strlen( pzData );
+    char    ch;
+    tMacro* pCM = pCurMacro;
+    tMacro  mac = { (teFuncType)~0, 0, 0, 0, 0, 0, 0, NULL };
 
-    pzEnd = (char*)skipScheme( pzData, pzEnd );
-    ch = *pzEnd;
-    *pzEnd = NUL;
-    gh_eval_str( (char*)pzData );
-    *pzEnd = ch;
+    mac.lineNo  = templLineNo;
+    pzEnd       = (char*)skipScheme( pzData, pzEnd );
+    ch          = *pzEnd;
+    *pzEnd      = NUL;
+    pCurMacro   = &mac;
+
+    ag_scm_c_eval_string_from_file_line(
+          (char*)pzData, pzFileName, templLineNo );
+
+    pCurMacro = pCM;
+    *pzEnd    = ch;
     while (pzData < pzEnd)
         if (*(pzData++) == '\n')
             templLineNo++;
@@ -384,7 +384,7 @@ loadPseudoMacro( tCC* pzData, tCC* pzFileName )
             break;
 
         case PM_TR_TEMPL_SCHEME:
-            pzData = doSchemeExpr( pzData, pzFileName, templLineNo );
+            pzData = doSchemeExpr( pzData, pzFileName );
             break;
 
         case PM_TR_END_MARK_ED_MODE:
@@ -427,7 +427,9 @@ loadPseudoMacro( tCC* pzData, tCC* pzFileName )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of loadPseudo.c */
+ * end of agen5/loadPseudo.c */
