@@ -1,6 +1,6 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
- * AutoGen Globally exported prototypes Sun Feb 16 12:05:33 PST 2003
+ * AutoGen Globally exported prototypes Sun Jun  1 11:40:46 PDT 2003
  */
 #ifndef AUTOGEN_PROTOTYPES_H
 #define AUTOGEN_PROTOTYPES_H
@@ -106,6 +106,11 @@ makeEmptyDefs( void );
 YYSTYPE
 identify( YYSTYPE template );
 
+/* exports from expGuile.c */
+
+SCM
+ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line );
+
 /* exports from expOutput.c */
 
 void
