@@ -1,12 +1,12 @@
 
 /*
- *  $Id: tpLoad.c,v 1.26 2002/09/30 03:12:51 bkorb Exp $
+ *  $Id: tpLoad.c,v 1.35 2003/05/31 22:59:15 bkorb Exp $
  *
  *  This module will load a template and return a template structure.
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -25,13 +25,6 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#include <sys/types.h>
-#include <sys/param.h>
-#include <sys/mman.h> 
-#include <fcntl.h>
-
-#include "autogen.h"
-
 static tTlibMark magicMark = TEMPLATE_MAGIC_MARKER;
 
 STATIC size_t countMacros( tCC* pz );
@@ -187,7 +180,6 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
         } while (--ct > 0);
     }
 
- findFileReturnFailure:
     res = FAILURE;
 
  findFileReturn:
@@ -353,24 +345,23 @@ mapDataFile( tCC* pzFileName, tMapInfo* pMapInfo, tCC** papSuffixList )
      *  Find the template file somewhere
      */
     if (! SUCCESSFUL( findFile( pzFileName, zRealFile, papSuffixList )))
-        AG_ABEND( asprintf( zCannot, ENOENT, "map data file",
-                            pzFileName, strerror( ENOENT )));
+        AG_ABEND( aprf( zCannot, ENOENT, "map data file", pzFileName,
+                        strerror( ENOENT )));
 
-    AGDUPSTR( pMapInfo->pzFileName, zRealFile, "map data file" );
+    AGDUPSTR( pMapInfo->pzFileName, zRealFile, "mmapped file name" );
 
     /*
      *  The template file must really be a file.
      */
     {
-        char* pz;
         struct stat stbf;
         if (stat( zRealFile, &stbf ) != 0)
-            AG_ABEND( asprintf( zCannot, errno, zOpen,
-                                zRealFile, strerror( errno )));
+            AG_ABEND( aprf( zCannot, errno, zOpen, zRealFile,
+                            strerror( errno )));
 
         if (! S_ISREG( stbf.st_mode ))
-            AG_ABEND( asprintf( zCannot, errno, zOpen,
-                                zRealFile, "wrong file type" ));
+            AG_ABEND( aprf( zCannot, errno, zOpen, zRealFile,
+                            "wrong file type" ));
 
         if (outTime <= stbf.st_mtime)
             outTime = stbf.st_mtime + 1;
@@ -382,16 +373,14 @@ mapDataFile( tCC* pzFileName, tMapInfo* pMapInfo, tCC** papSuffixList )
      */
     pMapInfo->fd = open( zRealFile, O_EXCL | O_RDONLY, 0 );
     if (pMapInfo->fd == -1)
-        AG_ABEND( asprintf( zCannot, errno, zOpen,
-                            zRealFile, strerror( errno )));
+        AG_ABEND( aprf( zCannot, errno, zOpen, zRealFile, strerror( errno )));
 
     pMapInfo->pData =
         mmap( NULL, pMapInfo->size, PROT_READ | PROT_WRITE,
               MAP_PRIVATE, pMapInfo->fd, (off_t)0 );
 
     if (pMapInfo->pData == (void*)(-1))
-        AG_ABEND( asprintf( zCannot, errno, "mmap",
-                            zRealFile, strerror( errno )));
+        AG_ABEND( aprf( zCannot, errno, "mmap", zRealFile, strerror( errno )));
 }
 
 
@@ -462,25 +451,15 @@ loadTemplate( tCC* pzFileName )
     }
 }
 
-#ifdef MEMDEBUG
-
-    void
+extern void
 unloadTemplate( tTemplate* pT )
 {
-    if (pT->fd < 0)
-        AGFREE( (void*)pT );
-    else {
-        int     fd = pT->fd;
-        void*   addr = (void*)pT;
-        size_t  size = pT->descSize;
-        close( fd );
-        munmap( addr, size );
-    }
 }
-#endif
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of tpLoad.c */
+ * end of agen5/tpLoad.c */
