@@ -1,7 +1,7 @@
 
 /*
  *  agTempl.c
- *  $Id: tpProcess.c,v 1.23 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: tpProcess.c,v 1.31 2003/05/24 02:40:43 bkorb Exp $
  *  Parse and process the template data descriptions
  */
 
@@ -25,10 +25,6 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#define HANDLE_FUNCTIONS
-#include "autogen.h"
-#include "expr.h"
-
 STATIC void openOutFile( tOutSpec* pOutSpec, tFpStack* pStk );
 
 STATIC tFpStack fpRoot = { 0, NULL, NULL, NULL };
@@ -46,8 +42,6 @@ generateBlock( tTemplate*   pT,
 {
     tSCC zFmt[] = "%-10s (%2X) in %s at line %d\n";
     int  fc;
-#   define HANDLE_FUNCTIONS
-#   include "functions.h"
 
     /*
      *  Set up the processing context for this block of macros.
@@ -91,23 +85,32 @@ STATIC void
 doStdoutTemplate( tTemplate* pTF )
 {
     tSCC zNone[]  = "* NONE *";
+    tSCC zBadR[]  = "%sBogus return from setjmp:  %d\n";
     int  jmpcode  = setjmp( fileAbort );
     SCM  res;
     tCC* pzRes;
 
+    pzLastScheme = NULL; /* We cannot be in Scheme processing */
+
     switch (jmpcode) {
     case SUCCESS:
         break;
 
     case PROBLEM:
-        if (*pzOopsPrefix != NUL)
-            fprintf( pfTrace, "%soutput was abandoned\n", pzOopsPrefix );
+        if (*pzOopsPrefix != NUL) {
+            fprintf( stdout, "%soutput was abandoned\n", pzOopsPrefix );
+            pzOopsPrefix = "";
+        }
         fclose( stdout );
         return;
 
     default:
-        fprintf( pfTrace, "%sBogus return from setjmp:  %d\n",
-                 pzOopsPrefix, jmpcode );
+        if (*pzOopsPrefix != NUL) {
+            fprintf( stdout, zBadR, pzOopsPrefix, jmpcode );
+            pzOopsPrefix = "";
+        } else {
+            fprintf( pfTrace, zBadR+2, jmpcode );
+        }
 
     case FAILURE:
         exit( EXIT_FAILURE );
@@ -172,6 +175,14 @@ processTemplate( tTemplate* pTF )
         tOutSpec*  pOS    = pOutSpecList;
         int        jumpCd = setjmp( fileAbort );
 
+        /*
+         * We cannot be in Scheme processing.  We've either just started
+         * or we've made a long jump from our own code.  If we've made a
+         * long jump, we've printed a message that is sufficient and we
+         * don't need to print any scheme expressions.
+         */
+        pzLastScheme = NULL;
+
         /*
          *  HOW was that we got here?
          */
@@ -306,14 +317,29 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
          */
         pStk->pzOutName = aprf( pOutSpec->pzFileFmt, pzDefFile,
                                 pOutSpec->zSuffix );
+        if (pStk->pzOutName == NULL)
+            AG_ABEND( aprf( "Cannot format file name:  ``%s''",
+                            pOutSpec->pzFileFmt ));
         if (p != NULL)
             *p = '.';
     }
 
     pCurFp = pStk;
 
-    if (strcmp( pOutSpec->zSuffix, "null" ) == 0)
-        goto openNull;
+    if (strcmp( pOutSpec->zSuffix, "null" ) == 0) {
+      null_open:
+        /*
+         *  Make the output a no-op, but perform the operations.
+         */
+        AGFREE( (void*)pStk->pzOutName );
+        pStk->pzOutName = (char*)zDevNull;
+        pStk->flags    |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
+        pStk->pFile     = fopen( zDevNull, "w" FOPEN_BINARY_FLAG "+" );
+        if (pStk->pFile != NULL)
+            return;
+
+        goto openError;
+    }
 
     /*
      *  IF we are to skip the current suffix,
@@ -325,36 +351,25 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
         char**  ppz = STACKLST_OPT( SKIP_SUFFIX );
 
         while (--ct >= 0) {
-            if (strcmp( pOutSpec->zSuffix, *ppz++ ) == 0) {
-
-            openNull:
-                /*
-                 *  Make the output a no-op, but perform the operations.
-                 */
-                AGFREE( (void*)pStk->pzOutName );
-                pStk->pzOutName = (char*)zDevNull;
-                pStk->flags    |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
-                pStk->pFile     = fopen( zDevNull, "w" FOPEN_BINARY_FLAG );
-                if (pStk->pFile != NULL)
-                    return;
-
-                goto openError;
-            }
+            if (strcmp( pOutSpec->zSuffix, *ppz++ ) == 0)
+                goto null_open;
         }
     }
 
     unlink( pStk->pzOutName );
-    pStk->pFile = fopen( pStk->pzOutName, "w" FOPEN_BINARY_FLAG );
+    pStk->pFile = fopen( pStk->pzOutName, "w+" FOPEN_BINARY_FLAG );
 
     if (pStk->pFile == NULL) {
     openError:
-        AG_ABEND( aprf( zCannot, pzProg, errno, "create",
-                        pStk->pzOutName, strerror( errno )));
+        AG_ABEND( aprf( zCannot, errno, "create", pStk->pzOutName,
+                        strerror( errno )));
     }
 }
 /*
  * Local Variables:
- * c-file-style: "Stroustrup"
+ * mode: C
+ * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of tpProcess.c */
+ * end of agen5/tpProcess.c */
