@@ -1,8 +1,8 @@
 
 /*
- *  Time-stamp:      "2003-01-05 11:20:13 bkorb"
+ *  Time-stamp:      "2003-05-26 08:04:30 bkorb"
  *
- *  autoopts.h  $Id: autoopts.h,v 2.33 2003/02/15 22:58:59 bkorb Exp $
+ *  autoopts.h  $Id: autoopts.h,v 2.38 2003/05/31 22:59:15 bkorb Exp $
  *
  *  This file defines all the global structures and special values
  *  used in the automated option processing library.
@@ -59,6 +59,9 @@
 #include "config.h"
 #include "compat/compat.h"
 #include <sys/param.h>
+#include <sys/wait.h>
+#include <time.h>
+#include <utime.h>
 
 #include "options.h"
 #include "streqv.h"
@@ -127,66 +130,15 @@ typedef struct {
     char*      pzOptArg;
 } tOptState;
 
-#if defined( __STDC__ ) || defined( __cplusplus )
-#  ifndef PROTO
-#    define PROTO(s) s
-#  endif
-
-#else
-#  ifndef PROTO
-#    define PROTO(s) ()
-#  endif
-
-#endif
-
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *
- *  MEMORY DEBUGGING
- */
-
-#ifndef AUTOGEN_BUILD
 #  define AGALOC( c, w )        malloc( c )
 #  define AGREALOC( p, c, w )   realloc( p, c )
-#  define AGDUPSTR( p, s, w )   strdup( p )
 #  define AGFREE( p )           free( p )
+#  define AGDUPSTR( p, s, w )   p = strdup( s )
 #  define TAGMEM( m, t )
 
-#else  /* AUTOGEN_BUILD is defined: */
+#ifdef AUTOGEN_BUILD
 #  include <snprintfv/printf.h>
-
-#  ifndef MEMDEBUG
-     extern void* aopts_alloc( size_t, const char* );
-     extern void* aopts_realloc( void*, size_t, const char* );
-     extern char* aopts_strdup( const char* pz, const char* );
-
-#    define AGALOC( c, w )      aopts_alloc( c, w )
-#    define AGREALOC( p, c, w ) aopts_realloc( p, c, w )
-#    define AGDUPSTR( p, s, w ) p = aopts_strdup( s, w )
-#    define AGFREE( p )         free( p )
-#    define TAGMEM( m, t )
-
-#  else  /* MEMDEBUG *IS* defined: */
-     typedef struct mem_mgmt      tMemMgmt;
-     struct mem_mgmt {
-         tMemMgmt*   pNext;
-         tMemMgmt*   pPrev;
-         char*       pEnd;
-         const char* pzWhence;
-     };
-
-     extern void* aopts_alloc( size_t, const char* );
-     extern void* aopts_realloc( void*, size_t, const char* );
-     extern char* aopts_strdup( const char* pz, const char* );
-     extern void  aopts_free( void* );
-
-#    define AO_HERE  " in " __FILE__ " at " STR( __LINE__ )
-#    define AGALOC( c, w )      aopts_alloc( c, w AO_HERE )
-#    define AGREALOC( p, c, w ) aopts_realloc( p, c, w AO_HERE )
-#    define AGDUPSTR( p, s, w ) p = aopts_strdup( s, w " - strdup" AO_HERE )
-#    define AGFREE( p )         aopts_free( p )
-#    define TAGMEM( m, t )      STMTS( tMemMgmt* p  = ((tMemMgmt*)m)-1; \
-                                p->pzWhence = t " - TAGGED" AO_HERE; )
-#  endif /* MEMDEBUG */
+#else  /* NOT AUTOGEN_BUILD */
 #endif /* AUTOGEN_BUILD */
 
 /*
@@ -198,13 +150,13 @@ extern FILE* option_usage_fp;
  *  optionUsage print the usage text for the program described by the
  *  option descriptor.  Does not return.  Calls ``exit(3)'' with exitCode.
  */
-extern void optionUsage PROTO(( tOptions*, int exitCode ));
+extern void optionUsage( tOptions*, int exitCode );
 
 /*
  *  optionSave saves the option state into an RC or INI file in
  *  the *LAST* defined directory in the papzHomeList.
  */
-void    optionSave PROTO((   tOptions* pOpts ));
+extern void optionSave( tOptions* pOpts );
 
 /*
  *  optionMakePath  --  translate and construct a path
@@ -213,16 +165,20 @@ void    optionSave PROTO((   tOptions* pOpts ));
  *  is a ``$''.  If it starts with two dollar characters, then the path
  *  is relative to the location of the executable.
  */
-ag_bool optionMakePath PROTO((
+extern ag_bool optionMakePath(
     char*    pzBuf,
     size_t   bufSize,
     tCC*     pzName,
-    tCC*     pzProgPath ));
+    tCC*     pzProgPath );
+
+extern tOptProc doVersion, doPagedUsage, doLoadOpt;
 
 #endif /* AUTOGEN_AUTOOPTS_H */
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * autoopts.h ends here */
+ * end of autoopts/autoopts.h */
