@@ -1,6 +1,6 @@
 
 /*
- *  $Id: boolean.c,v 2.6 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: boolean.c,v 2.8 2003/04/21 03:27:50 bkorb Exp $
  *
  *   Automated Options Paged Usage module.
  *
@@ -51,8 +51,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#include "autoopts.h"
-
 /*
  *  The value is true, unless it starts with 'n' or 'f' or "#f" or
  *  it is an empty string or it is a number that evaluates to zero
@@ -89,7 +87,9 @@ optionBooleanVal( pOpts, pOD )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * pgusage.c ends here */
+ * end of autoopts/boolean.c */
