@@ -1,6 +1,6 @@
 
 /*
- *  $Id: putshell.c,v 2.12 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: putshell.c,v 2.14 2003/04/21 03:27:50 bkorb Exp $
  *
  *  This module will interpret the options set in the tOptions
  *  structure and print them to standard out in a fashion that
@@ -50,9 +50,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#ifdef __STDC__
-#include "autoopts.h"
-
 /*
  *  Make sure embedded single quotes come out okay
  */
@@ -200,7 +197,7 @@ putBourneShell( tOptions* pOpts )
                 || (pOD->pzLastArg[0] == NUL) )
 
             printf( zOptNumFmt, pOpts->pzPROGNAME, pOD->pz_NAME,
-                    pOD->optOccCt );
+                    (int)pOD->optOccCt );
 
         /*
          *  This option has a text value
@@ -212,17 +209,12 @@ putBourneShell( tOptions* pOpts )
         }
     } while (++optIx < pOpts->presetOptCt );
 }
-#else
-int putBourneShell( pOpts )
-    char* pOpts;
-{
-    fputs( "putBourneShell disabled for pre-ANSI C\n", stderr );
-    exit( EXIT_FAILURE );
-}
-#endif
+
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * putshell.c ends here */
+ * end of autoopts/putshell.c */
