@@ -1,6 +1,6 @@
 
 /*
- *  save.c  $Id: save.c,v 3.3 2002/06/14 02:11:36 bkorb Exp $
+ *  save.c  $Id: save.c,v 2.24 2003/04/21 03:27:51 bkorb Exp $
  *
  *  This module's routines will take the currently set options and
  *  store them into an ".rc" file for re-interpretation the next
@@ -8,7 +8,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2002 Bruce Korb
+ *  Automated Options copyright 1992-2003 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -50,12 +50,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#include <compat/compat.h>
-
-#include <time.h>
-
-#include "autoopts.h"
-
 tSCC  zWarn[] = "%s WARNING:  cannot save options - ";
 
 STATIC char*
@@ -112,8 +106,12 @@ findDirName( pOpts )
         if (pzEndDir == (char*)NULL)
             return pzEnv;
 
-        pzFileName = (char*)AGALOC(( strlen( pzEnv ) + 2 +
-                     (pzEndDir != (char*)NULL) ? strlen( pzEndDir ) : 0 ));
+        {
+            size_t sz = strlen( pzEnv ) + 2;
+            if (pzEndDir != NULL)
+                sz += strlen( pzEndDir );
+            pzFileName = (char*)AGALOC( sz, "dir name" );
+        }
 
         /*
          *  IF we stripped something off, now tack it back on.
@@ -179,7 +177,7 @@ findFileName( pOpts )
                 *pzDirCh = '/';
                 stBuf.st_mode = S_IFREG;
 
-                break;  /* bail out of error condition */
+                continue;  /* bail out of error condition */
             }
 
             *pzDirCh = '/';
@@ -201,8 +199,12 @@ findFileName( pOpts )
         size_t sz = strlen( pzDir ) + strlen( pOpts->pzRcName ) + 2;
 
         {
-            char*  pzPath = (char*)AGALOC( sz );
+            char*  pzPath = (char*)AGALOC( sz, "file name" );
+#ifdef HAVE_SNPRINTF
             snprintf( pzPath, sz, "%s/%s", pzDir, pOpts->pzRcName );
+#else
+            sprintf( pzPath, "%s/%s", pzDir, pOpts->pzRcName );
+#endif
             pzDir = pzPath;
         }
 
@@ -252,7 +254,7 @@ printEntry( fp, p, pzLA )
     /*
      *  There is an argument.  Pad the name so values line up
      */
-    fprintf( fp, "%-18s  ",
+    fprintf( fp, "%-18s",
              (DISABLED_OPT( p )) ? p->pz_DisableName : p->pz_Name );
 
     /*
@@ -260,12 +262,16 @@ printEntry( fp, p, pzLA )
      *  THEN the char pointer is really the number
      */
     if ((p->fOptState & OPTST_NUMERIC) != 0)
-        fprintf( fp, "%ld\n", (t_word)pzLA );
+        fprintf( fp, "  %d\n", (t_word)pzLA );
 
     /*
      *  OTHERWISE, FOR each line of the value text, ...
      */
+    else if (pzLA == NULL)
+        fputc( '\n', fp );
+
     else {
+        fputc( ' ', fp ); fputc( ' ', fp );
         for (;;) {
             char* pzNl = strchr( pzLA, '\n' );
 
@@ -317,6 +323,9 @@ printEntry( fp, p, pzLA )
  * and do nothing.  If the output file cannot be created or updated, a message
  * will be printed to @code{stderr} and the routine will return.
 =*/
+#define ARGTYPE \
+  (OPTST_NUMERIC | OPTST_STACKED | OPTST_ENUMERATION | OPTST_BOOLEAN )
+
 void
 optionSaveFile( pOpts )
     tOptions* pOpts;
@@ -401,9 +410,14 @@ optionSaveFile( pOpts )
                 continue;
             }
 
-            if ((p->fOptState & OPTST_STACKED) == 0)
+            switch (p->fOptState & ARGTYPE) {
+            case 0:
+            case OPTST_NUMERIC:
                 printEntry( fp, p, p->pzLastArg );
-            else {
+                break;
+
+            case OPTST_STACKED:
+            {
                 tArgList*  pAL = (tArgList*)p->optCookie;
                 int        uct = pAL->useCt;
                 char**     ppz = pAL->apzArgs;
@@ -416,6 +430,29 @@ optionSaveFile( pOpts )
 
                 while (uct-- > 0)
                     printEntry( fp, p, *(ppz++) );
+                break;
+            }
+
+            case OPTST_ENUMERATION:
+            {
+                uintptr_t enumVal = (uintptr_t)(p->pzLastArg);
+                /*
+                 *  This is a magic incantation that will convert the
+                 *  enumeration value back into a string suitable for printing.
+                 *  We restore the numeric value after printing.
+                 */
+                (*(p->pOptProc))( (tOptions*)2UL, p );
+                printEntry( fp, p, p->pzLastArg );
+                p->pzLastArg = (char*)enumVal;
+                break;
+            }
+
+            case OPTST_BOOLEAN:
+                printEntry( fp, p, (p->pzLastArg != 0) ? "true" : "false" );
+                break;
+
+            default:
+                break; /* bogus - skip it */
             }
         } while ( (pOD++), (--ct > 0));
 
@@ -424,7 +461,9 @@ optionSaveFile( pOpts )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * save.c ends here */
+ * end of autoopts/save.c */
