@@ -1,13 +1,13 @@
 
 /*
  *  stack.c
- *  $Id: stack.c,v 2.13 2002/09/20 04:56:45 bkorb Exp $
+ *  $Id: stack.c,v 2.17 2003/04/21 03:27:51 bkorb Exp $
  *  This is a special option processing routine that will save the
  *  argument to an option in a FIFO queue.
  */
 
 /*
- *  Automated Options copyright 1992-2002 Bruce Korb
+ *  Automated Options copyright 1992-2003 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -49,7 +49,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#include "autoopts.h"
 #include REGEX_HEADER
 
 void
@@ -57,7 +56,6 @@ unstackOptArg( pOpts, pOptDesc )
     tOptions*  pOpts;
     tOptDesc*  pOptDesc;
 {
-    int       ct, i;
     int       res;
 
     tArgList* pAL = (tArgList*)pOptDesc->optCookie;
@@ -74,7 +72,7 @@ unstackOptArg( pOpts, pOptDesc )
 
     {
         regex_t   re;
-        int       ct, dIdx;
+        int       i, ct, dIdx;
 
         if (regcomp( &re, pOptDesc->pzLastArg, REG_NOSUB ) != 0)
             return;
@@ -179,7 +177,7 @@ stackOptArg( pOpts, pOptDesc )
      *  THEN allocate one now
      */
     if (pAL == (tArgList*)NULL) {
-        pAL = (tArgList*)AGALOC( sizeof( *pAL ), "open file stack entry" );
+        pAL = (tArgList*)AGALOC( sizeof( *pAL ), "new option arg stack" );
         if (pAL == (tArgList*)NULL)
             return;
         pAL->useCt   = 0;
@@ -199,7 +197,7 @@ stackOptArg( pOpts, pOptDesc )
          *  pointers.  We subtract it off to find our augment size.
          */
         sz += sizeof(char*) * (pAL->allocCt - MIN_ARG_ALLOC_CT);
-        pAL = (tArgList*)AGREALOC( (void*)pAL, sz, "open file stack entry" );
+        pAL = (tArgList*)AGREALOC( (void*)pAL, sz, "expanded opt arg stack" );
         if (pAL == (tArgList*)NULL)
             return;
     }
@@ -212,7 +210,9 @@ stackOptArg( pOpts, pOptDesc )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * stack.c ends here */
+ * end of autoopts/stack.c */
