@@ -1,6 +1,6 @@
 
 /*
- *  $Id: streqv.h,v 2.9 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: streqv.h,v 2.11 2003/04/29 01:42:37 bkorb Exp $
  *
  *  String Equivalence
  *
@@ -97,15 +97,12 @@ extern void streqvmap PROTO(( char chFrom, char chTo, int ct ));
  */
 extern void strtransform PROTO(( char* d, const char* s ));
 
-#ifdef MEMDEBUG
-extern void finalMemCheck( void );
-struct mem_mgmt;
-extern void checkMem( struct mem_mgmt* pMM );
-#endif
-
 #endif /* TOOLS_STREQUIVALENCE */
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
+ * indent-tabs-mode: nil
  * End:
- * streqv.h ends here */
+ * end of autoopts/streqv.h */
