@@ -1,6 +1,6 @@
 
 /*
- *  usage.c  $Id: usage.c,v 2.37 2003/03/15 17:52:02 bkorb Exp $
+ *  usage.c  $Id: usage.c,v 2.39 2003/04/21 03:27:51 bkorb Exp $
  *
  *  This module implements the default usage procedure for
  *  Automated Options.  It may be overridden, of course.
@@ -49,7 +49,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#include "autoopts.h"
 #define OPTPROC_L_N_S  (OPTPROC_LONGOPT | OPTPROC_SHORTOPT)
 tSCC zAlt[]        = "\t\t\t\t- an alternate for %s\n";
 tSCC zDefaultOpt[] = "\t\t\t\t- default option for unnamed options\n";
@@ -685,8 +684,9 @@ printInitList( papz, pInitIntro, pzRc, pzPN )
 
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
- * indent-tabs-mode: nil
  * tab-width: 4
+ * indent-tabs-mode: nil
  * End:
- * usage.c ends here */
+ * end of autoopts/usage.c */
