@@ -1,12 +1,12 @@
 
-/*  $Id: version.c,v 2.11 2002/07/26 04:22:12 bkorb Exp $
+/*  $Id: version.c,v 2.15 2003/04/21 03:27:51 bkorb Exp $
  *
  *  This module implements the default usage procedure for
  *  Automated Options.  It may be overridden, of course.
  */
 
 static const char zAOV[] =
-    "Automated Options version %s, copyright (c) 1999-2002 Bruce Korb\n";
+    "Automated Options version %s, copyright (c) 1999-2003 Bruce Korb\n";
 
 /*  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -48,11 +48,6 @@ static const char zAOV[] =
  * If you do not wish that, delete this exception notice.
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-
-#include "autoopts.h"
-
 tSCC zBadArg[] =
 "ERROR: version option argument '%c' invalid.  Use:\n\
 \t'v' - version only\n\
@@ -139,7 +134,9 @@ doVersionStderr( pOpts, pOD )
 
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * version.c ends here */
+ * end of autoopts/version.c */
