@@ -1,7 +1,7 @@
 
 /*
  *  columns.c
- *  $Id: columns.c,v 1.16 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: columns.c,v 1.20 2003/05/06 02:06:22 bkorb Exp $
  */
 
 /*
@@ -24,14 +24,6 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#include "config.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
-#include "opts.h"
-
 struct print_list {
     char**     papz;
     int        index;
@@ -63,7 +55,7 @@ void writeColumns( void );
 int  handleIndent( char* pzIndentArg );
 
 
-    int
+int
 main( int    argc,
       char** argv )
 {
@@ -138,11 +130,11 @@ main( int    argc,
 }
 
 
-    int
+int
 handleIndent( char* pzIndentArg )
 {
     char* pz;
-    long  colCt = strtol( pzIndentArg, &pz, 0 );
+    int   colCt = strtol( pzIndentArg, &pz, 0 );
 
     /*
      *  IF the indent argument is a number
@@ -188,8 +180,8 @@ handleIndent( char* pzIndentArg )
                 goto colsCounted;
 
             case '\t':
-                colCt += OPT_VALUE_TAB_WIDTH
-                       - (colCt % OPT_VALUE_TAB_WIDTH);
+                colCt += OPT_VALUE_TAB_WIDTH;
+                colCt -= (colCt % OPT_VALUE_TAB_WIDTH);
                 break;
 
             case '\n':
@@ -212,11 +204,10 @@ handleIndent( char* pzIndentArg )
 }
 
 
-    void
+void
 readLines( void )
 {
     int   sepLen;
-    char* pzText;
 
     if (HAVE_OPT( SEPARATION ))
          sepLen = strlen( OPT_ARG( SEPARATION ));
@@ -364,7 +355,7 @@ readLines( void )
 }
 
 
-    void
+void
 writeColumns( void )
 {
     char zFmt[ 12 ];
@@ -507,7 +498,7 @@ writeColumns( void )
 }
 
 
-    void
+void
 writeRows( void )
 {
     char zFmt[ 12 ];
@@ -592,7 +583,7 @@ writeRows( void )
 /*
  *  Line comparison procedure
  */
-    int
+int
 compProc( const void* p1, const void* p2 )
 {
     char* pz1 = *(char**)p1;
@@ -601,8 +592,9 @@ compProc( const void* p1, const void* p2 )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
- * indent-tabs-mode: nil
  * tab-width: 4
+ * indent-tabs-mode: nil
  * End:
- * end of columns.c */
+ * end of columns/columns.c */
