@@ -3,12 +3,12 @@
 /* --- fake the preprocessor into handlng portability */
 
 /*
+ *  Time-stamp:      "2002-09-21 13:38:29 bkorb"
+ *
  * Author:           Gary V Vaughan <gvaughan@oranda.demon.co.uk>
  * Created:          Mon Jun 30 15:54:46 1997
- * Last Modified:     Fri Jul 30 12:34:46 1999
- *            by: bkorb
  *
- * $Id: compat.h,v 2.9 2002/08/10 19:28:28 bkorb Exp $
+ * $Id: compat.h,v 2.12 2003/04/19 02:36:51 bkorb Exp $
  */
 #ifndef COMPAT_H
 #define COMPAT_H 1
@@ -54,10 +54,10 @@
 
 #ifdef STDC_HEADERS
 #  ifndef HAVE_STRING_H
-#     define HAVE_STRING_H	1
+#     define HAVE_STRING_H  1
 #  endif
 #  ifndef HAVE_STDLIB_H
-#     define HAVE_STDLIB_H	1
+#     define HAVE_STDLIB_H  1
 #  endif
 #endif
 
@@ -67,13 +67,21 @@
 #  error NEED <stdlib.h>
 #endif
 
-# ifdef HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #   include <unistd.h>
-# endif
+#endif
 
-# ifdef HAVE_ERRNO_H
+#ifdef HAVE_ERRNO_H
 #   include <errno.h>
-# endif
+#else
+#  error NEED <errno.h>
+#endif
+
+#ifdef HAVE_MEMORY_H
+#  include <memory.h>
+#else
+#  error NEED <memory.h>
+#endif
 
 /* some systems #def errno! and others do not declare it!! */
 #ifndef errno
@@ -113,21 +121,21 @@
 #endif /* MAXPATHLEN */
 
 # ifndef LONG_MAX
-#   define LONG_MAX	~(1L << (8*sizeof(long) -1))
-#   define INT_MAX	~(1 << (8*sizeof(int) -1))
-#   define SHORT_MAX	~(1 << (8*sizeof(short) -1))
+#   define LONG_MAX     ~(1L << (8*sizeof(long) -1))
+#   define INT_MAX      ~(1 << (8*sizeof(int) -1))
+#   define SHORT_MAX    ~(1 << (8*sizeof(short) -1))
 # endif
 
 # ifndef ULONG_MAX
-#   define ULONG_MAX	~(OUL)
-#   define UINT_MAX	~(OU)
-#   define USHORT_MAX	~(OUS)
+#   define ULONG_MAX    ~(OUL)
+#   define UINT_MAX     ~(OU)
+#   define USHORT_MAX   ~(OUS)
 # endif
 
 /* redefine these for BSD style string libraries */
 #ifndef HAVE_STRCHR
-#  define strchr		index
-#  define strrchr		rindex
+#  define strchr        index
+#  define strrchr       rindex
 #endif
 
 #if HAVE_STRING_H
@@ -138,10 +146,37 @@
    extern char *strchr(), *strrchr();
 #endif
 
-#ifdef HAVE_SETJMP_H
-#  include <setjmp.h>
-#else
-#  error NEED <setjmp.h>
+#if defined(HAVE_LIBGEN) && defined(HAVE_LIBGEN_H)
+#  include <libgen.h>
+#endif
+
+#ifndef HAVE_PATHFIND
+  EXTERN char *pathfind PARAMS((const char *, const char *, const char *));
+#endif
+
+#ifndef NULL
+#  define NULL 0
+#endif
+
+#ifndef FOPEN_BINARY_FLAG
+#  ifdef USE_FOPEN_BINARY
+#    define FOPEN_BINARY_FLAG   "b"
+#  else
+#    define FOPEN_BINARY_FLAG
+#  endif
+#endif
+
+#ifndef FOPEN_TEXT_FLAG
+#  ifdef USE_TEXT_BINARY
+#    define FOPEN_TEXT_FLAG     "t"
+#  else
+#    define FOPEN_TEXT_FLAG
+#  endif
+#endif
+
+#ifndef STR
+#  define _STR(s) #s
+#  define STR(s)  _STR(s)
 #endif
 
 /* ##### Pointer sized word ##### */
@@ -157,9 +192,13 @@
    #define WORD_MIN  INT_MIN
 #endif
 
-#ifndef HAVE_PATHFIND
-  EXTERN char *pathfind PARAMS((const char *, const char *, const char *));
-#endif
+# if defined (_POSIX_SOURCE)
+/* Posix does not require that the d_ino field be present, and some
+   systems do not provide it. */
+#    define REAL_DIR_ENTRY(dp) 1
+# else /* !_POSIX_SOURCE */
+#    define REAL_DIR_ENTRY(dp) (dp->d_ino != 0)
+# endif /* !_POSIX_SOURCE */
 
 # if defined (HAVE_DIRENT_H)
 #   include <dirent.h>
@@ -176,23 +215,25 @@
 #   if defined (HAVE_NDIR_H)
 #     include <ndir.h>
 #   endif /* HAVE_NDIR_H */
-#   if !defined (HAVE_SYS_NDIR_H) && !defined (HAVE_SYS_DIR_H) && !defined (HAVE_NDIR_H)
+#   if !defined (HAVE_SYS_NDIR_H) && \
+       !defined (HAVE_SYS_DIR_H)  && \
+       !defined (HAVE_NDIR_H)
 #     include "ndir.h"
 #   endif /* !HAVE_SYS_NDIR_H && !HAVE_SYS_DIR_H && !HAVE_NDIR_H */
 # endif /* !HAVE_DIRENT_H */
 
-# if defined (_POSIX_SOURCE)
-/* Posix does not require that the d_ino field be present, and some
-   systems do not provide it. */
-#    define REAL_DIR_ENTRY(dp) 1
-# else /* !_POSIX_SOURCE */
-#    define REAL_DIR_ENTRY(dp) (dp->d_ino != 0)
-# endif /* !_POSIX_SOURCE */
-
-#if defined(HAVE_LIBGEN) && defined(HAVE_LIBGEN_H)
-#  include <libgen.h>
+#ifdef HAVE_SETJMP_H
+#  include <setjmp.h>
+#else
+#  error NEED <setjmp.h>
 #endif
 
 #endif /* COMPAT_H */
-
-/* compat.h ends here */
+/*
+ * Local Variables:
+ * mode: C
+ * c-file-style: "stroustrup"
+ * tab-width: 4
+ * indent-tabs-mode: nil
+ * End:
+ * compat.h ends here */
