@@ -1,15 +1,14 @@
 /*
- *  $Id: gdemit.c,v 2.3 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: gdemit.c,v 2.5 2003/04/22 01:35:45 bkorb Exp $
  *
  *    getdefs copyright 1999-2003 Bruce Korb
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
  *  Maintainer:        Bruce Korb <bkorb@gnu.org>
  *  Created:           Sat Dec 1, 2001
- *  Last Modified:     $Date: 2003/02/15 22:58:59 $
+ *  Last Modified:     $Date: 2003/04/22 01:35:45 $
  *            by:      Bruce Korb <bkorb@gnu.org>
  */
-#include "getdefs.h"
 
 /* FORWARD */
 
@@ -555,4 +554,4 @@ emitSubblockString( char** ppzText, char sepChar, char* pzOut )
  * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of gdemit.c */
+ * end of getdefs/gdemit.c */
