@@ -1,15 +1,14 @@
 /*
- *  $Id: gdinit.c,v 2.2 2002/05/05 04:03:35 bkorb Exp $
+ *  $Id: gdinit.c,v 2.6 2003/04/22 01:35:46 bkorb Exp $
  *
- *    getdefs copyright 1999-2001 Bruce Korb
+ *    getdefs copyright 1999-2003 Bruce Korb
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
  *  Maintainer:        Bruce Korb <bkorb@gnu.org>
  *  Created:           Sat Dec 1, 2001
- *  Last Modified:     $Date: 2002/05/05 04:03:35 $
+ *  Last Modified:     $Date: 2003/04/22 01:35:46 $
  *            by: bkorb
  */
-#include "getdefs.h"
 
 tSCC zNoList[] = "ERROR:  block attr must have name list:\n\t%s\n";
 
@@ -159,6 +158,12 @@ loadStdin( void )
     int    ct  = 0;
     char** ppz = STACKLST_OPT( INPUT );
 
+    if (isatty( STDIN_FILENO )) {
+        fputs( "getdefs error:  no inputs were specified and stdin is a tty\n",
+               stderr );
+        USAGE( EXIT_FAILURE );
+    }
+
     while (fgets( z, sizeof( z ), stdin ) != NULL) {
         char* pz = z + strlen( z );
 
@@ -309,6 +314,9 @@ validateOptions( void )
         } while (--ct > 0);
     }
 
+    if (! HAVE_OPT( INPUT ))
+        SET_OPT_INPUT( "-" );
+
     /*
      *  Make sure each of the input files is findable.
      *  Also, while we are at it, compute the output file mod time
@@ -402,4 +410,4 @@ validateOptions( void )
  * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of gdinit.c */
+ * end of getdefs/gdinit.c */
