@@ -159,6 +159,8 @@ typedef int snv_wint_t;
 #  endif
 #endif
 
+#undef  _STR
+#undef  _CONC
 #ifdef __STDC__
 #  define _STR(x)		#x
 #  define _CONC(x, y)	x##y
@@ -303,17 +305,8 @@ typedef int compatboolean;
 typedef SNV_LONG_DOUBLE snv_long_double;
 
 #ifndef HAVE_STRTOUL
-extern unsigned long strtoul( const char *nptrm,
-							  char **endptr,
-							  register int base );
-#endif
-
-#ifndef HAVE_LDEXPL
-extern long double ldexpl(long double x, int exp);
-#endif
-
-#ifndef HAVE_FREXPL
-extern long double frexpl(long double x, int *exp);
+extern unsigned long
+strtoul( const char *nptrm, char **endptr, register int base );
 #endif
 
 SNV_END_EXTERN_C
