@@ -149,12 +149,12 @@ typedef union printf_arg
  *
  * Append an error that will be returned by printf_strerror.
  */
-#define PRINTF_ERROR(pi, str)                                         \
+#define PRINTF_ERROR(pi, str) \
         printf_error(pi, __FILE__, __LINE__, SNV_ASSERT_FCN, str);
-
-typedef int printf_function PARAMS ((STREAM *stream, struct printf_info *pparser, union printf_arg const * args));
-
-typedef int printf_arginfo_function PARAMS ((struct printf_info *pparser, size_t n, int *argtypes));
+typedef int printf_function (STREAM *stream, struct printf_info *pparser,
+							 union printf_arg const * args);
+typedef int printf_arginfo_function (struct printf_info *pparser, size_t n,
+									 int *argtypes);
 
 /**
  * spec_entry:
@@ -199,7 +199,7 @@ spec_entry;
  * Returns %NULL if @func was not successfully registered, a
  * %spec_entry with the information on the function if it was.
  **/
-typedef spec_entry *register_callback_function PARAMS ((unsigned spec, printf_function *func, printf_arginfo_function *arginfo));
+typedef spec_entry *register_callback_function (unsigned spec, printf_function *func, printf_arginfo_function *arginfo);
 
 /* Codes to determine basic types.
 
@@ -249,15 +249,11 @@ enum
       { \
 	if (count >= 0) \
 	  { \
-	    int m_status = stream_put((ch), stream); \
+	    int m_status = stream_put((unsigned char)(ch), stream); \
 	    count = m_status < 0 ? m_status : count + m_status; \
 	  } \
       } \
-    else \
-      { \
-        (void)(ch); \
-	count++; \
-      } \
+    else count++; \
   } SNV_STMT_END
 
 /**
@@ -276,28 +272,15 @@ enum
  * Return value:
  * Always 1.
  */
-extern int printf_generic_info PARAMS((struct printf_info *const pinfo, size_t n, int *argtypes));
+extern int printf_generic_info (struct printf_info *const pinfo, size_t n, int *argtypes);
 
-/**
- * printf_generic:   
- * @stream: the stream (possibly a struct printfv_stream appropriately
- * cast) on which to write output.
- * @pinfo: the current state information for the format string parser.
- * @args: the pointer to the first argument to be read by the handler
- *
- * An example implementation of a %printf_function, used to provide easy
- * access to justification, width and precision options.
- *
- * Return value:
- * The number of characters output.
- **/
-extern int printf_generic PARAMS((STREAM *stream, struct printf_info *const pinfo, union printf_arg const *args));
 
 /**
  * register_printf_function:  
  * @spec: the character which will trigger @func, cast to an unsigned int.
  * @fmt: the handler function to actually print the arguments to the specifier
- * @arg: the handler function to tell %printf about the types of the arguments to the specifier
+ * @arg: the handler function to tell %printf about the types of the arguments
+ *       to the specifier
  * 
  * Register the pair made of @fmt and @arg, so that it is called
  * when @spec is encountered in a format string.
@@ -306,7 +289,8 @@ extern int printf_generic PARAMS((STREAM *stream, struct printf_info *const pinf
  * Returns %NULL if @func was not successfully registered, a
  * %spec_entry with the information on the function if it was.
  **/
-extern spec_entry * register_printf_function PARAMS((unsigned spec, printf_function *fmt, printf_arginfo_function *arg));
+extern spec_entry * register_printf_function (unsigned spec, printf_function *fmt, printf_arginfo_function *arg);
+
 
 /**
  * printf_strerror:  
@@ -319,7 +303,8 @@ extern spec_entry * register_printf_function PARAMS((unsigned spec, printf_funct
  * parsing of a printf format string.  It is the responsibility
  * of the caller to free the string.
  */
-extern char * printf_strerror PARAMS(());
+extern char * printf_strerror (void);
+
 
 /**
  * printf_error:  
@@ -339,7 +324,8 @@ extern char * printf_strerror PARAMS(());
  * The address of the full accumulated error message in @pinfo is
  * returned.
  **/
-extern char * printf_error PARAMS((struct printf_info *pinfo, const char *file, int line, const char *func1, const char *func2, const char *func3, const char *error_message));
+extern char * printf_error (struct printf_info *pinfo, const char *file, int line, const char *func1, const char *func2, const char *func3, const char *error_message);
+
 
 /**
  * parse_printf_format:  
@@ -361,7 +347,8 @@ extern char * printf_error PARAMS((struct printf_info *pinfo, const char *file,
  * this function again. If there is an error, then %SNV_ERROR
  * is returned instead.
  **/
-extern size_t parse_printf_format PARAMS((const char *format, int n, int *argtypes));
+extern size_t parse_printf_format (const char *format, int n, int *argtypes);
+
 
 /**
  * stream_printfv:  
@@ -377,7 +364,8 @@ extern size_t parse_printf_format PARAMS((const char *format, int n, int *argtyp
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int stream_printfv PARAMS((STREAM *stream, const char *format, snv_constpointer const *ap));
+extern int stream_printfv (STREAM *stream, const char *format, snv_constpointer const *ap);
+
 
 /**
  * stream_vprintf:  
@@ -393,7 +381,8 @@ extern int stream_printfv PARAMS((STREAM *stream, const char *format, snv_constp
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int stream_vprintf PARAMS((STREAM *stream, const char *format, va_list ap));
+extern int stream_vprintf (STREAM *stream, const char *format, va_list ap);
+
 
 /**
  * stream_printf:  
@@ -413,7 +402,7 @@ extern int stream_printf SNV_GNUC_PRINTF((STREAM * stream, const char *format, .
 
 
 /**
- * fdputc:  
+ * snv_fdputc:  
  * @ch: A single character to be added to @stream.
  * @stream: The stream in which to write @ch.
  * 
@@ -424,7 +413,8 @@ extern int stream_printf SNV_GNUC_PRINTF((STREAM * stream, const char *format, .
  * The value of @ch that has been put in @stream, or -1 in case of
  * an error (errno will be set to indicate the type of error).
  **/
-extern int fdputc PARAMS((int ch, STREAM *stream));
+extern int snv_fdputc (int ch, STREAM *stream);
+
 
 /**
  * snv_dprintf:  
@@ -455,10 +445,11 @@ extern int snv_dprintf SNV_GNUC_PRINTF((int fd, const char *format, ...), 2, 3);
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int snv_vdprintf PARAMS((int fd, const char *format, va_list ap));
+extern int snv_vdprintf (int fd, const char *format, va_list ap);
+
 
 /**
- * dprintfv:  
+ * snv_dprintfv:  
  * @fd: an open file descriptor.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
@@ -470,10 +461,11 @@ extern int snv_vdprintf PARAMS((int fd, const char *format, va_list ap));
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int dprintfv PARAMS((int fd, const char *format, snv_constpointer const args[]));
+extern int snv_dprintfv (int fd, const char *format, snv_constpointer const args[]);
+
 
 /**
- * fileputc:  
+ * snv_fileputc:  
  * @ch: A single character to be added to @stream.
  * @stream: The stream in which to write @ch.
  * 
@@ -483,7 +475,8 @@ extern int dprintfv PARAMS((int fd, const char *format, snv_constpointer const a
  * Return value: 
  * The value of @ch that has been put in @stream.
  **/
-extern int fileputc PARAMS((int ch, STREAM *stream));
+extern int snv_fileputc (int ch, STREAM *stream);
+
 
 /**
  * snv_printf:  
@@ -512,10 +505,11 @@ extern int snv_printf SNV_GNUC_PRINTF((const char *format, ...), 1, 2);
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int snv_vprintf PARAMS((const char *format, va_list ap));
+extern int snv_vprintf (const char *format, va_list ap);
+
 
 /**
- * printfv:  
+ * snv_printfv:  
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
  * 
@@ -526,7 +520,8 @@ extern int snv_vprintf PARAMS((const char *format, va_list ap));
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int printfv PARAMS((const char *format, snv_constpointer const args[]));
+extern int snv_printfv (const char *format, snv_constpointer const args[]);
+
 
 /**
  * snv_fprintf:  
@@ -557,10 +552,11 @@ extern int snv_fprintf SNV_GNUC_PRINTF((FILE * file, const char *format, ...), 2
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int snv_vfprintf PARAMS((FILE *file, const char *format, va_list ap));
+extern int snv_vfprintf (FILE *file, const char *format, va_list ap);
+
 
 /**
- * fprintfv:  
+ * snv_fprintfv:  
  * @file: a stdio.h FILE* stream.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
@@ -572,10 +568,11 @@ extern int snv_vfprintf PARAMS((FILE *file, const char *format, va_list ap));
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int fprintfv PARAMS((FILE *file, const char *format, snv_constpointer const args[]));
+extern int snv_fprintfv (FILE *file, const char *format, snv_constpointer const args[]);
+
 
 /**
- * bufputc:  
+ * snv_bufputc:  
  * @ch: A single character to be added to @stream.
  * @stream: The stream in which to write @ch.
  * 
@@ -585,7 +582,7 @@ extern int fprintfv PARAMS((FILE *file, const char *format, snv_constpointer con
  * Return value:
  * The value of @ch that has been put in @stream.
  **/
-extern int bufputc PARAMS((int ch, STREAM *stream));
+extern int snv_bufputc (int ch, STREAM *stream);
 
 /**
  * snv_sprintf:  
@@ -616,10 +613,11 @@ extern int snv_sprintf SNV_GNUC_PRINTF((char buffer[], const char *format, ...),
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int snv_vsprintf PARAMS((char buffer[], const char *format, va_list ap));
+extern int snv_vsprintf (char buffer[], const char *format, va_list ap);
+
 
 /**
- * sprintfv:  
+ * snv_sprintfv:  
  * @buffer: a preallocated char* buffer.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
@@ -631,7 +629,8 @@ extern int snv_vsprintf PARAMS((char buffer[], const char *format, va_list ap));
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int sprintfv PARAMS((char buffer[], const char *format, snv_constpointer const args[]));
+extern int snv_sprintfv (char buffer[], const char *format, snv_constpointer const args[]);
+
 
 /**
  * snv_snprintf:  
@@ -666,10 +665,11 @@ extern int snv_snprintf SNV_GNUC_PRINTF((char buffer[], unsigned long limit, con
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int snv_vsnprintf PARAMS((char buffer[], unsigned long limit, const char *format, va_list ap));
+extern int snv_vsnprintf (char buffer[], unsigned long limit, const char *format, va_list ap);
+
 
 /**
- * snprintfv:  
+ * snv_snprintfv:  
  * @buffer: a preallocated char* buffer.
  * @limit: the maximum number of characters to write into @buffer.
  * @format: a % delimited format string.
@@ -683,10 +683,11 @@ extern int snv_vsnprintf PARAMS((char buffer[], unsigned long limit, const char
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int snprintfv PARAMS((char buffer[], unsigned long limit, const char *format, snv_constpointer const args[]));
+extern int snv_snprintfv (char buffer[], unsigned long limit, const char *format, snv_constpointer const args[]);
+
 
 /**
- * filputc:  
+ * snv_filputc:  
  * @ch: A single character to be added to @stream.
  * @stream: The stream in which to write @ch.
  * 
@@ -696,7 +697,7 @@ extern int snprintfv PARAMS((char buffer[], unsigned long limit, const char *for
  * Return value: 
  * The value of @ch that has been put in @stream.
  **/
-extern int filputc PARAMS((int ch, STREAM *stream));
+extern int snv_filputc (int ch, STREAM *stream);
 
 /**
  * snv_asprintf:  
@@ -738,10 +739,11 @@ extern int snv_asprintf SNV_GNUC_PRINTF((char **result, const char *format, ...)
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int snv_vasprintf PARAMS((char **result, const char *format, va_list ap));
+extern int snv_vasprintf (char **result, const char *format, va_list ap);
+
 
 /**
- * asprintfv:  
+ * snv_asprintfv:  
  * @result: the address of a char * variable.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
@@ -757,25 +759,33 @@ extern int snv_vasprintf PARAMS((char **result, const char *format, va_list ap))
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
  **/
-extern int asprintfv PARAMS((char **result, const char *format, snv_constpointer const args[]));
+extern int snv_asprintfv (char **result, const char *format, snv_constpointer const args[]);
+
 
 
 /* If you don't want to use snprintfv functions for *all* of your string
    formatting API, then define COMPILING_SNPRINTFV_C and use the snv_
    prefix for the entry points below. */
 #ifndef COMPILING_PRINTF_C
-#undef printf
-#undef vprintf
-#undef dprintf
-#undef vdprintf
-#undef fprintf
-#undef vfprintf
-#undef sprintf
-#undef vsprintf
-#undef snprintf
-#undef vsnprintf
-#undef asprintf
-#undef vasprintf
+#undef  printf
+#undef  vprintf
+#undef  dprintf
+#undef  vdprintf
+#undef  fprintf
+#undef  vfprintf
+#undef  sprintf
+#undef  vsprintf
+#undef  snprintf
+#undef  vsnprintf
+#undef  asprintf
+#undef  vasprintf
+#undef  asprintfv
+#undef  dprintfv
+#undef  fprintfv
+#undef  sprintfv
+#undef  printfv
+#undef  snprintfv
+
 #define printf          snv_printf
 #define vprintf         snv_vprintf
 #define dprintf         snv_dprintf
@@ -788,6 +798,12 @@ extern int asprintfv PARAMS((char **result, const char *format, snv_constpointer
 #define vsnprintf       snv_vsnprintf
 #define asprintf        snv_asprintf
 #define vasprintf       snv_vasprintf
+#define asprintfv       snv_asprintfv
+#define dprintfv        snv_dprintfv
+#define fprintfv        snv_fprintfv
+#define sprintfv        snv_sprintfv
+#define printfv         snv_printfv
+#define snprintfv       snv_snprintfv
 #endif				/* !COMPILING_SNPRINTFV_C */
 #ifdef __cplusplus
 }
