@@ -1,7 +1,7 @@
 
 /*
  *  xml2ag.c
- *  $Id: xml2ag.c,v 1.7 2003/02/15 22:59:00 bkorb Exp $
+ *  $Id: xml2ag.c,v 1.11 2003/05/18 18:19:40 bkorb Exp $
  *  This is the main routine for xml2ag.
  */
 
@@ -25,11 +25,6 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#include <libxml/parser.h>
-#include <libxml/tree.h>
-
-#include "xmlopts.h"
-
 tSCC zConflict[] =
     "the file name operand conflicts with the definitions option.\n";
 
@@ -37,7 +32,7 @@ tSCC zTextFmt[] =
     "text = '%s';\n";
 
 
-static const char* typeName[] = {
+tSCC* typeName[] = {
     "0 - inval",
     "ELEMENT_NODE",
     "ATTRIBUTE_NODE",
@@ -88,7 +83,7 @@ printHeader( xmlDocPtr pDoc );
 STATIC void
 printAttrs( xmlAttrPtr pAttr );
 
-STATIC int
+STATIC void
 printNode( xmlNodePtr pNode );
 
 STATIC void
@@ -97,17 +92,19 @@ printChildren( xmlNodePtr pNode );
 /* = = = END-STATIC-FORWARD = = = */
 #define TRIM(s,psz) trim( (const char*)(s), (size_t*)(psz) )
 
+extern void forkAutogen( char* pzInput );
+
 
 int
 main( int argc, char** argv )
 {
-	xmlDocPtr pDoc;
+    xmlDocPtr pDoc;
     char*     pzFile = NULL;
 
-	{
-		int ct = optionProcess( &xml2agOptions, argc, argv );
-		argc -= ct;
-		argv += ct;
+    {
+        int ct = optionProcess( &xml2agOptions, argc, argv );
+        argc -= ct;
+        argv += ct;
 
         switch (argc) {
         case 1:
@@ -130,23 +127,23 @@ main( int argc, char** argv )
             fprintf( stderr, "only one argument allowed\n" );
             return EXIT_FAILURE;
         }
-	}
+    }
 
     if (! HAVE_OPT( OUTPUT ))
         forkAutogen( pzFile );
     else
         outFp = stdout;
 
-	if (pzFile != NULL) {
+    if (pzFile != NULL) {
         fprintf( outFp, "/* Parsing file %s */\n", pzFile );
-		pDoc = xmlParseFile( pzFile );
+        pDoc = xmlParseFile( pzFile );
     }
-	else {
-		size_t sz;
-		char*  pz = loadFile( stdin, &sz );
-		pDoc = xmlParseMemory( pz, sz );
+    else {
+        size_t sz;
+        char*  pz = loadFile( stdin, &sz );
+        pDoc = xmlParseMemory( pz, sz );
         fprintf( outFp, "/* Parsed from stdin */\n" );
-	}
+    }
 
     {
         xmlNodePtr pRoot = printHeader( pDoc );
@@ -163,7 +160,7 @@ main( int argc, char** argv )
     }
 
     xmlCleanupParser();
-	return 0;
+    return 0;
 }
 
 
@@ -171,32 +168,32 @@ main( int argc, char** argv )
 STATIC char*
 loadFile( FILE* fp, size_t* pzSize )
 {
-	size_t  asz = CHUNK_SZ;
-	size_t  usz = 0;
-	char*   mem = malloc( asz );
+    size_t  asz = CHUNK_SZ;
+    size_t  usz = 0;
+    char*   mem = malloc( asz );
 
-	for (;;) {
+    for (;;) {
 
-		if ((usz + CHUNK_SZ) > asz) {
-			asz += CHUNK_SZ;
-			mem = realloc( mem, asz );
-		}
+        if ((usz + CHUNK_SZ) > asz) {
+            asz += CHUNK_SZ;
+            mem = realloc( mem, asz );
+        }
 
         if (mem == NULL) {
             fprintf( stderr, "Cannot allocate %d byte bufer\n", asz );
             exit( EXIT_FAILURE );
         }
 
-		{
-			size_t rdct = fread( mem + usz, 1, CHUNK_SZ, fp );
-			usz += rdct;
-			if (rdct < CHUNK_SZ)
-				break;
-		}
-	}
+        {
+            size_t rdct = fread( mem + usz, 1, CHUNK_SZ, fp );
+            usz += rdct;
+            if (rdct < CHUNK_SZ)
+                break;
+        }
+    }
 
-	*pzSize = usz;
-	return mem;
+    *pzSize = usz;
+    return mem;
 }
 
 
@@ -211,39 +208,79 @@ emitIndentation( void )
 STATIC char*
 trim( const char* pzSrc, size_t* pSz )
 {
-    static char z[ 4096 * 16 ];
-    size_t len;
-    const char* pzEnd;
+    static char*  pzData  = NULL;
+    static size_t dataLen = 0;
+    size_t        strSize;
 
     if (pzSrc == NULL) {
-        z[0] = '\0';
         if (pSz != NULL) *pSz = 0;
-        return z;
+        return "";
     }
 
+    /*
+     *  Trim leading and trailing white space.
+     */
     while (isspace( *pzSrc ))  pzSrc++;
-    pzEnd = pzSrc + strlen( pzSrc );
-    while ((pzEnd > pzSrc) && isspace( pzEnd[-1] ))  pzEnd--;
 
-    if (pzEnd <= pzSrc) {
-        z[0] = '\0';
-        if (pSz != NULL) *pSz = 0;
-    } else {
-        char* pzDest = z;
+    {
+        const char* pzEnd = pzSrc + strlen( pzSrc );
+        while ((pzEnd > pzSrc) && isspace( pzEnd[-1] ))  pzEnd--;
+
+        if (pzEnd <= pzSrc) {
+            if (pSz != NULL) *pSz = 0;
+            return "";
+        }
+        strSize = (pzEnd - pzSrc);
+    }
+
+    /*
+     *  Count the extra backslashes required and ensure our buffer is
+     *  big enough to hold the newly formed string.
+     */
+    {
+        const char* pz = pzSrc;
+        for (;;) {
+            pz += strcspn( pz, "'\\" );
+            if (*(pz++) == NUL)
+                break;
+            strSize++;
+        }
+    }
+
+    if (dataLen <= strSize) {
+        size_t sz = (strSize + 0x1000) & ~0x0FFF;
+        if (pzData != NULL)
+             pzData = malloc( sz );
+        else pzData = realloc( pzData, sz );
+        if (pzData == NULL) {
+            fprintf( stderr, "ENOMEM allocating 0x%lX bytes", sz );
+            exit( EXIT_FAILURE );
+        }
+        dataLen = sz;
+    }
+
+    /*
+     *  Copy the data, adding backslashes in front of
+     *  single quotes and backslashes.
+     */
+    {
+        char* pzDest = pzData;
         for (;;) {
             switch (*(pzDest++) = *(pzSrc++)) {
-            case '\'': strcpy( (pzDest++)-1, "\\'" ); break;
+            case '\'': pzDest[-1]  = '\\'; *(pzDest++) = '\''; break;
             case '\\': *(pzDest++) = '\\'; break;
+            case NUL:  goto set_size;
             }
-            if (pzSrc == pzEnd)
+            if (pzDest == pzData + strSize)
                 break;
         }
 
         *pzDest = '\0';
-        if (pSz != NULL) *pSz = pzDest - &(z[0]);
     }
 
-    return z;
+ set_size:
+    if (pSz != NULL) *pSz = strSize;
+    return pzData;
 }
 
 STATIC xmlNodePtr
@@ -329,7 +366,7 @@ printAttrs( xmlAttrPtr pAttr )
 }
 
 
-STATIC int
+STATIC void
 printNode( xmlNodePtr pNode )
 {
     switch (pNode->type) {
@@ -439,8 +476,9 @@ printChildren( xmlNodePtr pNode )
 
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
- * indent-tabs-mode: nil
  * tab-width: 4
+ * indent-tabs-mode: nil
  * End:
- * end of autogen.c */
+ * end of xml2ag/xml2ag.c */
